#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: Hrishikesh Terdalkar (hrishikeshrt.samskrit@gmail.com)

Perl Source:
    Samsaadhanii Git (sandhi/any_sandhi.pl)
    (Commit: 4c9331a53059d3153f97e46e949decc755749180)
"""

###############################################################################
#  Copyright for the Perl-based implementation
#
#  Copyright (C) 2002-2012 Pankaj Vyas
#  Copyright (C) 2002-2012 Sivaja Nair
#  Copyright (C) 2002-2013 Amba Kulkarni (ambapradeep@gmail.com)
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either
#  version 2 of the License, or (at your option) any later
#  version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
###############################################################################

RULES = [
    "a,a,A,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),awra+api",
    "a,A,A,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),rAma+Alayam",
    "a,i,e,guNa,Ax guNaH (6.1.87),xeva+inxraH",
    "a,I,e,guNa,Ax guNaH (6.1.87),gaNa+ISaH",
    "a,u,o,guNa,Ax guNaH (6.1.87),sUrya+uxayaH",
    "a,U,o,guNa,Ax guNaH (6.1.87),eka+UnaviMSaxi",
    "a,q,ar,guNa,Ax guNaH (6.1.87),sapwa+qRayaH",
    "a,q,a q,prakqwiBAva,qwyakaH (6.1.128),sapwa+qRayaH",
    "a,Q,ar,guNa,Ax guNaH (6.1.87),upa+QkArIyawi",
    "a,L,al,guNa,Ax guNaH (6.1.87),wava+LkAraH",
    "a,L,a L,prakqwiBAva,qwyakaH (6.1.128),wava+LkAraH",
    "a,e,E,vqxXi,vqxXireci (6.1.88),eka+ekam",
    "a,E,E,vqxXi,vqxXireci (6.1.88),wava+ESvaryam",
    "a,o,O,vqxXi,vqxXireci (6.1.88),wasya+oxanaH",
    "a,O,O,vqxXi,vqxXireci (6.1.88),mama+ORaXam",
    "a,k,ak,varNamelana,,,",
    "a,K,aK,varNamelana,,,",
    "a,g,ag,varNamelana,,,",
    "a,G,aG,varNamelana,,,",
    "a,f,af,varNamelana,,,",
    "a,c,ac,varNamelana,,,",
    "a,C,acC,wugAgama -> jaSwva-> Scuwva-> carwva,Ce ca (6.1.73)-> JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),SuBra+Cavi",
    "a,j,aj,varNamelana,,,",
    "a,J,aJ,varNamelana,,,",
    "a,F,aF,varNamelana,,,",
    "a,t,at,varNamelana,,,",
    "a,T,aT,varNamelana,,,",
    "a,d,ad,varNamelana,,,",
    "a,D,aD,varNamelana,,,",
    "a,N,aN,varNamelana,,,",
    "a,w,aw,varNamelana,,,",
    "a,W,aW,varNamelana,,,",
    "a,x,ax,varNamelana,,,",
    "a,X,aX,varNamelana,,,",
    "a,n,an,varNamelana,,,",
    "a,p,ap,varNamelana,,,",
    "a,P,aP,varNamelana,,,",
    "a,b,ab,varNamelana,,,",
    "a,B,aB,varNamelana,,,",
    "a,m,am,varNamelana,,,",
    "a,y,ay,varNamelana,,,",
    "a,r,ar,varNamelana,,,",
    "a,l,al,varNamelana,,,",
    "a,v,av,varNamelana,,,",
    "a,S,aS,varNamelana,,,",
    "a,R,aR,varNamelana,,,",
    "a,s,as,varNamelana,,,",
    "a,h,ah,varNamelana,,,",
    "A,a,A,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),vixyA+aByAsaH",
    "A,A,A,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),vixyA+AlayaH",
    "A,i,e,guNa,Ax guNaH (6.1.87),mahA+inxraH",
    "A,I,e,guNa,Ax guNaH (6.1.87),mahA+ISaH",
    "A,u,o,guNa,Ax guNaH (6.1.87),mahA+uwsavaH",
    "A,U,o,guNa,Ax guNaH (6.1.87),mahA+UrmiH",
    "A,q,ar,guNa,Ax guNaH (6.1.87),mahA+qRayaH",
    "A,q,a q,prakqwiBAva,qwyakaH (6.1.128),mahA+qRayaH",
    "A,Q,ar,guNa,Ax guNaH (6.1.87),mahA+QkAraH",
    "A,L,al,guNa,Ax guNaH (6.1.87),mahA+LkAraH",
    "A,L,A L,prakqwiBAva,qwyakaH (6.1.128),mahA+LkAraH",
    "A,e,E,vqxXi,vqxXireci (6.1.88),saxA+eva",
    "A,E,E,vqxXi,vqxXireci (6.1.88),mahA+ESvaryam",
    "A,o,O,vqxXi,vqxXireci (6.1.88),gafgA+oGaH",
    "A,O,O,vqxXi,vqxXireci (6.1.88),mahA+Owsukyam",
    "A,k,Ak,varNamelana,,,",
    "A,K,AK,varNamelana,,,",
    "A,g,Ag,varNamelana,,,",
    "A,G,AG,varNamelana,,,",
    "A,f,Af,varNamelana,,,",
    "A,c,Ac,varNamelana,,,",
    "A,C,AC,pakRe wugaBAvaH,,,",
    "A,C,AcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),SoBAnA+CaviH",
    "A,j,Aj,varNamelana,,,",
    "A,J,AJ,varNamelana,,,",
    "A,F,AF,varNamelana,,,",
    "A,t,At,varNamelana,,,",
    "A,T,AT,varNamelana,,,",
    "A,d,Ad,varNamelana,,,",
    "A,D,AD,varNamelana,,,",
    "A,N,AN,varNamelana,,,",
    "A,w,Aw,varNamelana,,,",
    "A,W,AW,varNamelana,,,",
    "A,x,Ax,varNamelana,,,",
    "A,X,AX,varNamelana,,,",
    "A,n,An,varNamelana,,,",
    "A,p,Ap,varNamelana,,,",
    "A,P,AP,varNamelana,,,",
    "A,b,Ab,varNamelana,,,",
    "A,B,AB,varNamelana,,,",
    "A,m,Am,varNamelana,,,",
    "A,y,Ay,varNamelana,,,",
    "A,r,Ar,varNamelana,,,",
    "A,l,Al,varNamelana,,,",
    "A,v,Av,varNamelana,,,",
    "A,S,AS,varNamelana,,,",
    "A,R,AR,varNamelana,,,",
    "A,s,As,varNamelana,,,",
    "A,h,Ah,varNamelana,,,",
    "i,a,ya,yaN,iko yaNaci (6.1.77),yaxi+api",
    "i,A,yA,yaN,iko yaNaci (6.1.77),iwi+AXunikaH",
    "i,i,I,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),kavi+inxraH",
    "i,I,I,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),kavi+ISaH",
    "i,u,yu,yaN,iko yaNaci (6.1.77),iwi+uvAca",
    "i,U,yU,yaN,iko yaNaci (6.1.77),iwi+UcuH",
    "i,q,yq,yaN,iko yaNaci (6.1.77),xaXi+qwe",
    "i,q,i q,prakqwiBAva,qwyakaH (6.1.128),xaXi+qwe",
    "i,Q,yQ,yaN,iko yaNaci (6.1.77),api+QkArayawi",
    "i,L,yL,yaN,iko yaNaci (6.1.77),api+LkArayawi",
    "i,L,i L,prakqwiBAva,qwyakaH (6.1.128),api+LkArayawi",
    "i,e,ye,yaN,iko yaNaci (6.1.77),prawi+ekam",
    "i,E,yE,yaN,iko yaNaci (6.1.77),kavi+Esvaryam",
    "i,o,yo,yaN,iko yaNaci (6.1.77),xaXi+oxanam",
    "i,O,yO,yaN,iko yaNaci (6.1.77),ravi+OwkaNTyam",
    "i,k,ik,varNamelana,,,",
    "i,K,iK,varNamelana,,,",
    "i,g,ig,varNamelana,,,",
    "i,G,iG,varNamelana,,,",
    "i,f,if,varNamelana,,,",
    "i,c,ic,varNamelana,,,",
    "i,C,icC,wugAgama -> jaSwva-> Scuwva-> carwva,Ce ca (6.1.73)-> JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "i,j,ij,varNamelana,,,",
    "i,J,iJ,varNamelana,,,",
    "i,F,iF,varNamelana,,,",
    "i,t,it,varNamelana,,,",
    "i,T,iT,varNamelana,,,",
    "i,d,id,varNamelana,,,",
    "i,D,iD,varNamelana,,,",
    "i,N,iN,varNamelana,,,",
    "i,w,iw,varNamelana,,,",
    "i,W,iW,varNamelana,,,",
    "i,x,ix,varNamelana,,,",
    "i,X,iX,varNamelana,,,",
    "i,n,in,varNamelana,,,",
    "i,p,ip,varNamelana,,,",
    "i,P,iP,varNamelana,,,",
    "i,b,ib,varNamelana,,,",
    "i,B,iB,varNamelana,,,",
    "i,m,im,varNamelana,,,",
    "i,y,iy,varNamelana,,,",
    "i,r,ir,varNamelana,,,",
    "i,l,il,varNamelana,,,",
    "i,v,iv,varNamelana,,,",
    "i,S,iS,varNamelana,,,",
    "i,R,iR,varNamelana,,,",
    "i,s,is,varNamelana,,,",
    "i,h,ih,varNamelana,,,",
    "I,a,ya,yaN,iko yaNaci (6.1.77),naxI+awra",  # here first prakqwiBAva then yaNAxeSa.
    "I,a,i a,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),naxI+awra",  # here first prakqwiBAva then yaNAxeSa.
    "I,A,yA,yaN,iko yaNaci (6.1.77),naxI+AkqwiH",
    "I,A,i A,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),naxI+AkqwiH",
    "I,i,I,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),pqWivI+inxuH",
    "I,I,I,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),mahI+ISaH",
    "I,u,yu,yaN,iko yaNaci (6.1.77),naxI+upaxiSawi",
    "I,u,i u,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),naxI+upaxiSawi",
    "I,U,yU,yaN,iko yaNaci (6.1.77),",
    "I,U,i U,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "I,q,yq,yaN,iko yaNaci (6.1.77),swrI+qNam",
    "I,q,i q,prakqwiBAva,qwyakaH (6.1.128),swrI+qNam",
    "I,Q,yQ,yaN,iko yaNaci (6.1.77),",
    "I,Q,i Q,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "I,L,yL,yaN,iko yaNaci (6.1.77),",
    "I,L,i L,prakqwiBAva,qwyakaH (6.1.128),",
    "I,e,ye,yaN,iko yaNaci (6.1.77),girI+ewO",
    "I,e,i e,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),girI+ewO",
    "I,E,yE,yaN,iko yaNaci (6.1.77),naxI+Edasya",
    "I,E,i E,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),naxI+Edasya",
    "I,o,yo,yaN,iko yaNaci (6.1.77),",
    "I,o,i o,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "I,O,yO,yaN,iko yaNaci (6.1.77),",
    "I,O,i O,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "I,k,Ik,varNamelana,,,",
    "I,K,IK,varNamelana,,,",
    "I,g,Ig,varNamelana,,,",
    "I,G,IG,varNamelana,,,",
    "I,f,If,varNamelana,,,",
    "I,c,Ic,varNamelana,,,",
    "I,C,IcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "I,C,IC,pakRe wugaBAvaH,,,",
    "I,j,Ij,varNamelana,,,",
    "I,J,IJ,varNamelana,,,",
    "I,F,IF,varNamelana,,,",
    "I,t,It,varNamelana,,,",
    "I,T,IT,varNamelana,,,",
    "I,d,Id,varNamelana,,,",
    "I,D,ID,varNamelana,,,",
    "I,N,IN,varNamelana,,,",
    "I,w,Iw,varNamelana,,,",
    "I,W,IW,varNamelana,,,",
    "I,x,Ix,varNamelana,,,",
    "I,X,IX,varNamelana,,,",
    "I,n,In,varNamelana,,,",
    "I,p,Ip,varNamelana,,,",
    "I,P,IP,varNamelana,,,",
    "I,b,Ib,varNamelana,,,",
    "I,B,IB,varNamelana,,,",
    "I,m,Im,varNamelana,,,",
    "I,y,Iy,varNamelana,,,",
    "I,r,Ir,varNamelana,,,",
    "I,l,Il,varNamelana,,,",
    "I,v,Iv,varNamelana,,,",
    "I,S,IS,varNamelana,,,",
    "I,R,IR,varNamelana,,,",
    "I,s,Is,varNamelana,,,",
    "I,h,Ih,varNamelana,,,",
    "u,a,va,yaN,iko yaNaci (6.1.77),manu+anwaram",
    "u,A,vA,yaN,iko yaNaci (6.1.77),manu+Agamanam",
    "u,i,vi,yaN,iko yaNaci (6.1.77),sAXu+ixam",
    "u,I,vI,yaN,iko yaNaci (6.1.77),maWu+Iha",
    "u,u,U,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),BAnu+uxayaH",
    "u,U,U,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),sAXu+UcuH",
    "u,q,vq,yaN,iko yaNaci (6.1.77),guru+qNam",  # here first prakqwiBAva then yaNAxeSaH
    "u,q,u q,prakqwiBAva,qwyakaH (6.1.128),guru+qNam",  # here first prakqwiBAvaH then yaNAxeSaH
    "u,Q,vQ,yaN,iko yaNaci (6.1.77),sAWu+QkAraH",
    "u,L,vL,yaN,iko yaNaci (6.1.77),sAWu+LkAraH",
    "u,L,u L,prakqwiBAva,qwyakaH (6.1.128),sAWu+LkAraH",
    "u,e,ve,yaN,iko yaNaci (6.1.77),anu+eRaNam",
    "u,E,vE,yaN,iko yaNaci (6.1.77),BAnu+Ewihyam",
    "u,o,vo,yaN,iko yaNaci (6.1.77),",
    "u,O,vO,yaN,iko yaNaci (6.1.77),",
    "u,k,uk,varNamelana,,,",
    "u,K,uK,varNamelana,,,",
    "u,g,ug,varNamelana,,,",
    "u,G,uG,varNamelana,,,",
    "u,f,uf,varNamelana,,,",
    "u,c,uc,varNamelana,,,",
    "u,C,ucC,wugAgama -> jaSwva-> Scuwva-> carwva,Ce ca (6.1.73)-> JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "u,j,uj,varNamelana,,,",
    "u,J,uJ,varNamelana,,,",
    "u,F,uF,varNamelana,,,",
    "u,t,ut,varNamelana,,,",
    "u,T,uT,varNamelana,,,",
    "u,d,ud,varNamelana,,,",
    "u,D,uD,varNamelana,,,",
    "u,N,uN,varNamelana,,,",
    "u,w,uw,varNamelana,,,",
    "u,W,uW,varNamelana,,,",
    "u,x,ux,varNamelana,,,",
    "u,X,uX,varNamelana,,,",
    "u,n,un,varNamelana,,,",
    "u,p,up,varNamelana,,,",
    "u,P,uP,varNamelana,,,",
    "u,b,ub,varNamelana,,,",
    "u,B,uB,varNamelana,,,",
    "u,m,um,varNamelana,,,",
    "u,y,uy,varNamelana,,,",
    "u,r,ur,varNamelana,,,",
    "u,l,ul,varNamelana,,,",
    "u,v,uv,varNamelana,,,",
    "u,S,uS,varNamelana,,,",
    "u,R,uR,varNamelana,,,",
    "u,s,us,varNamelana,,,",
    "u,h,uh,varNamelana,,,",
    "U,a,va,yaN,iko yaNaci (6.1.77),",
    "U,a,u a,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,A,vA,yaN,iko yaNaci (6.1.77),vaXU+Agamanam",
    "U,A,u A,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),vaXU+Agamanam",
    "U,i,vi,yaN,iko yaNaci (6.1.77),",
    "U,i,u i,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,I,vI,yaN,iko yaNaci (6.1.77),sAXU+imO",
    "U,I,u I,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),sAXU+imO",
    "U,u,U,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),vaXU+uwsAhaH",
    "U,U,U,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),vaXU+UrmikA",
    "U,q,vq,yaN,iko yaNaci (6.1.77),vaXU+qNam",
    "U,q,u q,prakqwiBAva,qwyakaH (6.1.128),vaXU+qNam",
    "U,Q,vQ,yaN,iko yaNaci (6.1.77),",
    "U,Q,u Q,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,L,vL,yaN,iko yaNaci (6.1.77),",
    "U,L,u L,prakqwiBAva,qwyakaH (6.1.128),",
    "U,e,ve,yaN,iko yaNaci (6.1.77),",
    "U,e,u e,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,E,vE,yaN,iko yaNaci (6.1.77),",
    "U,E,u E,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,o,vo,yaN,iko yaNaci (6.1.77),",
    "U,o,u o,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "U,O,vO,yaN,iko yaNaci (6.1.77),vaXU+O",
    "U,O,u O,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),vaXU+O",
    "U,k,Uk,varNamelana,,,",
    "U,K,UK,varNamelana,,,",
    "U,g,Ug,varNamelana,,,",
    "U,G,UG,varNamelana,,,",
    "U,f,Uf,varNamelana,,,",
    "U,c,Uc,varNamelana,,,",
    "U,C,UcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76) -> swoH ScunA ScuH (8.4.40),",
    "U,C,UC,pakRe wugaBAvaH,,,",
    "U,j,Uj,varNamelana,,,",
    "U,J,UJ,varNamelana,,,",
    "U,F,UF,varNamelana,,,",
    "U,t,Ut,varNamelana,,,",
    "U,T,UT,varNamelana,,,",
    "U,d,Ud,varNamelana,,,",
    "U,D,UD,varNamelana,,,",
    "U,N,UN,varNamelana,,,",
    "U,w,Uw,varNamelana,,,",
    "U,W,UW,varNamelana,,,",
    "U,x,Ux,varNamelana,,,",
    "U,X,UX,varNamelana,,,",
    "U,n,Un,varNamelana,,,",
    "U,p,Up,varNamelana,,,",
    "U,P,UP,varNamelana,,,",
    "U,b,Ub,varNamelana,,,",
    "U,B,UB,varNamelana,,,",
    "U,m,Um,varNamelana,,,",
    "U,y,Uy,varNamelana,,,",
    "U,r,Ur,varNamelana,,,",
    "U,l,Ul,varNamelana,,,",
    "U,v,Uv,varNamelana,,,",
    "U,S,US,varNamelana,,,",
    "U,R,UR,varNamelana,,,",
    "U,s,Us,varNamelana,,,",
    "U,h,Uh,varNamelana,,,",
    "q,a,ra,yaN,iko yaNaci (6.1.77),XAwq+amSaH",
    "q,A,rA,yaN,iko yaNaci (6.1.77),piwq+A",
    "q,i,ri,yaN,iko yaNaci (6.1.77),piwq+icCa",
    "q,I,rI,yaN,iko yaNaci (6.1.77),karwq+I",
    "q,u,ru,yaN,iko yaNaci (6.1.77),karwq+uwa",
    "q,U,rU,yaN,iko yaNaci (6.1.77),",
    "q,q,q,qwva,qwi savarNe q vA (vA 3640),piwq+qNam",
    "q,q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),piwq+qNam",
    "q,q,q q,prakqwiBAva,qwyakaH (6.1.128),piwq+qNam",
    "q,Q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),howq+QkAram",
    "q,L,L,Lwva,Lwi savarNe L vA (vA 3641),piwq+qNam",
    "q,L,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),howq+LkAraH",
    "q,L,q L,prakqwiBAva,qwyakaH (6.1.128),howq+LkAraH",
    "q,e,re,yaN,iko yaNaci (6.1.77),mAwq+e",
    "q,E,rE,yaN,iko yaNaci (6.1.77),",
    "q,o,ro,yaN,iko yaNaci (6.1.77),mAwq+os",
    "q,O,rO,yaN,iko yaNaci (6.1.77),mAwq+OwkaNTyam",
    "q,k,qk,varNamelana,,,",
    "q,K,qK,varNamelana,,,",
    "q,g,qg,varNamelana,,,",
    "q,G,qG,varNamelana,,,",
    "q,f,qf,varNamelana,,,",
    "q,c,qc,varNamelana,,,",
    "q,C,qcC,wugAgama -> jaSwva-> Scuwva-> carwva,Ce ca (6.1.73)-> JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "q,j,qj,varNamelana,,,",
    "q,J,qJ,varNamelana,,,",
    "q,F,qF,varNamelana,,,",
    "q,t,qt,varNamelana,,,",
    "q,T,qT,varNamelana,,,",
    "q,d,qd,varNamelana,,,",
    "q,D,qD,varNamelana,,,",
    "q,N,qN,varNamelana,,,",
    "q,w,qw,varNamelana,,,",
    "q,W,qW,varNamelana,,,",
    "q,x,qx,varNamelana,,,",
    "q,X,qX,varNamelana,,,",
    "q,n,qn,varNamelana,,,",
    "q,p,qp,varNamelana,,,",
    "q,P,qP,varNamelana,,,",
    "q,b,qb,varNamelana,,,",
    "q,B,qB,varNamelana,,,",
    "q,m,qm,varNamelana,,,",
    "q,y,qy,varNamelana,,,",
    "q,r,qr,varNamelana,,,",
    "q,l,ql,varNamelana,,,",
    "q,v,qv,varNamelana,,,",
    "q,S,qS,varNamelana,,,",
    "q,R,qR,varNamelana,,,",
    "q,s,qs,varNamelana,,,",
    "q,h,qh,varNamelana,,,",
    "Q,a,ra,yaN,iko yaNaci (6.1.77),",
    "Q,a,q a,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,A,rA,yaN,iko yaNaci (6.1.77),",
    "Q,A,q A,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,i,ri,yaN,iko yaNaci (6.1.77),",
    "Q,i,q i,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,I,rI,yaN,iko yaNaci (6.1.77),",
    "Q,I,q I,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,u,ru,yaN,iko yaNaci (6.1.77),",
    "Q,u,q u,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,U,rU,yaN,iko yaNaci (6.1.77),",
    "Q,U,q U,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "Q,q,q,qwva,qwi savarNe q vA (vA 3640),piwq+qNam",
    "Q,q,q q,prakqwiBAva,qwyakaH (6.1.128),",
    "Q,Q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "Q,L,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "Q,L,q L,prakqwiBAva,qwyakaH (6.1.128),",
    "Q,L,L,Lwva,Lwi savarNe L vA (vA 3641),piwq+qNam",
    "Q,e,re,yaN,iko yaNaci (6.1.77),",
    "Q,e,q e,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,E,rE,yaN,iko yaNaci (6.1.77),",
    "Q,E,q E,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,o,ro,yaN,iko yaNaci (6.1.77),",
    "Q,o,q o,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,O,rO,yaN,iko yaNaci (6.1.77),",
    "Q,O,q O,prakqwiBAva,ikoZsavarNe SAkalyasya hrasvaSca (6.1.127),",
    "Q,k,Qk,varNamelana,,,",
    "Q,K,QK,varNamelana,,,",
    "Q,g,Qg,varNamelana,,,",
    "Q,G,QG,varNamelana,,,",
    "Q,f,Qf,varNamelana,,,",
    "Q,c,Qc,varNamelana,,,",
    "Q,C,QcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "Q,C,QC,pakRe wugaBAvaH,,,",
    "Q,j,Qj,varNamelana,,,",
    "Q,J,QJ,varNamelana,,,",
    "Q,F,QF,varNamelana,,,",
    "Q,t,Qt,varNamelana,,,",
    "Q,T,QT,varNamelana,,,",
    "Q,d,Qd,varNamelana,,,",
    "Q,D,QD,varNamelana,,,",
    "Q,N,QN,varNamelana,,,",
    "Q,w,Qw,varNamelana,,,",
    "Q,W,QW,varNamelana,,,",
    "Q,x,Qx,varNamelana,,,",
    "Q,X,QX,varNamelana,,,",
    "Q,n,Qn,varNamelana,,,",
    "Q,p,Qp,varNamelana,,,",
    "Q,P,QP,varNamelana,,,",
    "Q,b,Qb,varNamelana,,,",
    "Q,B,QB,varNamelana,,,",
    "Q,m,Qm,varNamelana,,,",
    "Q,y,Qy,varNamelana,,,",
    "Q,r,Qr,varNamelana,,,",
    "Q,l,Ql,varNamelana,,,",
    "Q,v,Qv,varNamelana,,,",
    "Q,S,QS,varNamelana,,,",
    "Q,R,QR,varNamelana,,,",
    "Q,s,Qs,varNamelana,,,",
    "Q,h,Qh,varNamelana,,,",
    "L,a,la,yaN,iko yaNaci (6.1.77),",
    "L,A,lA,yaN,iko yaNaci (6.1.77),GasL+AxeSaH",
    "L,i,li,yaN,iko yaNaci (6.1.77),",
    "L,I,lI,yaN,iko yaNaci (6.1.77),",
    "L,u,lu,yaN,iko yaNaci (6.1.77),",
    "L,U,lU,yaN,iko yaNaci (6.1.77),",
    "L,q,q,qwva,qwi savarNe q vA (vA 3640),piwq+qNam",
    "L,q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "L,q,L q,prakqwiBAva,qwyakaH (6.1.128),",
    "L,Q,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "L,L,L,Lwva,Lwi savarNe L vA (vA 3641),piwq+qNam",
    "L,L,Q,savarNaxIrGa,akaH savarNe xIrGaH (6.1.101),",
    "L,L,L L,prakqwiBAva,qwyakaH (6.1.128),",
    "L,e,le,yaN,iko yaNaci (6.1.77),",
    "L,E,lE,yaN,iko yaNaci (6.1.77),",
    "L,o,lo,yaN,iko yaNaci (6.1.77),",
    "L,O,lO,yaN,iko yaNaci (6.1.77),",
    "L,k,Lk,varNamelana,,,",
    "L,K,LK,varNamelana,,,",
    "L,g,Lg,varNamelana,,,",
    "L,G,LG,varNamelana,,,",
    "L,f,Lf,varNamelana,,,",
    "L,c,Lc,varNamelana,,,",
    "L,C,LcC,wugAgama -> jaSwva-> Scuwva-> carwva,Ce ca (6.1.73)-> JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "L,j,Lj,varNamelana,,,",
    "L,J,LJ,varNamelana,,,",
    "L,F,LF,varNamelana,,,",
    "L,t,Lt,varNamelana,,,",
    "L,T,LT,varNamelana,,,",
    "L,d,Ld,varNamelana,,,",
    "L,D,LD,varNamelana,,,",
    "L,N,LN,varNamelana,,,",
    "L,w,Lw,varNamelana,,,",
    "L,W,LW,varNamelana,,,",
    "L,x,Lx,varNamelana,,,",
    "L,X,LX,varNamelana,,,",
    "L,n,Ln,varNamelana,,,",
    "L,p,Lp,varNamelana,,,",
    "L,P,LP,varNamelana,,,",
    "L,b,Lb,varNamelana,,,",
    "L,B,LB,varNamelana,,,",
    "L,m,Lm,varNamelana,,,",
    "L,y,Ly,varNamelana,,,",
    "L,r,Lr,varNamelana,,,",
    "L,l,Ll,varNamelana,,,",
    "L,v,Lv,varNamelana,,,",
    "L,S,LS,varNamelana,,,",
    "L,R,LR,varNamelana,,,",
    "L,s,Ls,varNamelana,,,",
    "L,h,Lh,varNamelana,,,",
    "e,a,eZ,pUrvarUpa,efaH paxAnwAxawi (6.1.109),we+awra",
    "e,A,ayA,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),hare+AgacCa",
    "e,A,a A,lopa,lopaH SAkalyasya (8.3.19),hare+AgacCa",
    "e,i,ayi,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),Pale+icCa",
    "e,i,a i,lopa,lopaH SAkalyasya (8.3.19),Pale+icCa",
    "e,I,ayI,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),Pale+IhA",
    "e,I,a I,lopa,lopaH SAkalyasya (8.3.19),Pale+IhA",
    "e,u,ayu,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),kate+upaveSanam",
    "e,u,a u,lopa,lopaH SAkalyasya (8.3.19),kate+upaveSanam",
    "e,U,ayU,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),gurave+Uhawe",
    "e,U,a U,lopa,lopaH SAkalyasya (8.3.19),gurave+Uhawe",
    "e,q,ayq,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),haraye+qcCawi",
    "e,q,a q,lopa,lopaH SAkalyasya (8.3.19),haraye+qcCawi",
    "e,Q,ayQ,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "e,Q,a Q,lopa,lopaH SAkalyasya (8.3.19),",
    "e,L,ayL,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "e,L,a L,lopa,lopaH SAkalyasya (8.3.19),",
    "e,e,aye,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),kriyawe+eva",
    "e,e,a e,lopa,lopaH SAkalyasya (8.3.19),kriyawe+eva",
    "e,E,ayE,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),haraye+EkRawa",
    "e,E,a E,lopa,lopaH SAkalyasya (8.3.19),haraye+EkRawa",
    "e,o,ayo,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),haraye+oxanam",
    "e,o,a o,lopa,lopaH SAkalyasya (8.3.19),haraye+oxanam",
    "e,O,ayO,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),viRNave+ORaXam",
    "e,O,a O,lopa,lopaH SAkalyasya (8.3.19),viRNave+ORaXam",
    "e,k,ek,varNamelana,,,",
    "e,K,eK,varNamelana,,,",
    "e,g,eg,varNamelana,,,",
    "e,G,eG,varNamelana,,,",
    "e,f,ef,varNamelana,,,",
    "e,c,ec,varNamelana,,,",
    "e,C,ecC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "e,C,eC,pakRe wugaBAvaH,,,",
    "e,j,ej,varNamelana,,,",
    "e,J,eJ,varNamelana,,,",
    "e,F,eF,varNamelana,,,",
    "e,t,et,varNamelana,,,",
    "e,T,eT,varNamelana,,,",
    "e,d,ed,varNamelana,,,",
    "e,D,eD,varNamelana,,,",
    "e,N,eN,varNamelana,,,",
    "e,w,ew,varNamelana,,,",
    "e,W,eW,varNamelana,,,",
    "e,x,ex,varNamelana,,,",
    "e,X,eX,varNamelana,,,",
    "e,n,en,varNamelana,,,",
    "e,p,ep,varNamelana,,,",
    "e,P,eP,varNamelana,,,",
    "e,b,eb,varNamelana,,,",
    "e,B,eB,varNamelana,,,",
    "e,m,em,varNamelana,,,",
    "e,y,ey,varNamelana,,,",
    "e,r,er,varNamelana,,,",
    "e,l,el,varNamelana,,,",
    "e,v,ev,varNamelana,,,",
    "e,S,eS,varNamelana,,,",
    "e,R,eR,varNamelana,,,",
    "e,s,es,varNamelana,,,",
    "e,h,eh,varNamelana,,,",
    "E,a,Aya,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),SriyE+aswi",
    "E,a,A a,lopa,lopaH SAkalyasya (8.3.19),SriyE+aswi",
    "E,A,AyA,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),SriyE+Aha",
    "E,A,A A,lopa,lopaH SAkalyasya (8.3.19),SriyE+Aha",
    "E,i,Ayi,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasyE+ixam",
    "E,i,A i,lopa,lopaH SAkalyasya (8.3.19),wasyE+ixam",
    "E,I,AyI,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasyE+Ihawe",
    "E,I,A I,lopa,lopaH SAkalyasya (8.3.19),wasyE+Ihawe",
    "E,u,Ayu,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasyE+uvAca",
    "E,u,A u,lopa,lopaH SAkalyasya (8.3.19),wasyE+uvAca",
    "E,U,AyU,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasyE+Uhawe",
    "E,U,A U,lopa,lopaH SAkalyasya (8.3.19),wasyE+Uhawe",
    "E,q,Ayq,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),SriyE+qcCawi",
    "E,q,A q,lopa,lopaH SAkalyasya (8.3.19),SriyE+qcCawi",
    "E,Q,AyQ,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "E,Q,A Q,lopa,lopaH SAkalyasya (8.3.19),",
    "E,L,AyL,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "E,L,A L,lopa,lopaH SAkalyasya (8.3.19),",
    "E,e,Aye,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),SriyE+ewa",
    "E,e,A e,lopa,lopaH SAkalyasya (8.3.19),SriyE+ewa",
    "E,E,AyE,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),SriyE+EkRyawa",
    "E,E,A E,lopa,lopaH SAkalyasya (8.3.19),SriyE+EkRyawa",
    "E,o,Ayo,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasyE+oxanam",
    "E,o,A o,lopa,lopaH SAkalyasya (8.3.19),wasyE+oxanam",
    "E,O,AyO,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasmE+ORaXam",
    "E,O,A O,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),wasmE+ORaXam",
    "E,k,Ek,varNamelana,,,",
    "E,K,EK,varNamelana,,,",
    "E,g,Eg,varNamelana,,,",
    "E,G,EG,varNamelana,,,",
    "E,f,Ef,varNamelana,,,",
    "E,c,Ec,varNamelana,,,",
    "E,C,EcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "E,C,EC,pakRe wugaBAvaH,,,",
    "E,j,Ej,varNamelana,,,",
    "E,J,EJ,varNamelana,,,",
    "E,F,EF,varNamelana,,,",
    "E,t,Et,varNamelana,,,",
    "E,T,ET,varNamelana,,,",
    "E,d,Ed,varNamelana,,,",
    "E,D,ED,varNamelana,,,",
    "E,N,EN,varNamelana,,,",
    "E,w,Ew,varNamelana,,,",
    "E,W,EW,varNamelana,,,",
    "E,x,Ex,varNamelana,,,",
    "E,X,EX,varNamelana,,,",
    "E,n,En,varNamelana,,,",
    "E,p,Ep,varNamelana,,,",
    "E,P,EP,varNamelana,,,",
    "E,b,Eb,varNamelana,,,",
    "E,B,EB,varNamelana,,,",
    "E,m,Em,varNamelana,,,",
    "E,y,Ey,varNamelana,,,",
    "E,r,Er,varNamelana,,,",
    "E,l,El,varNamelana,,,",
    "E,v,Ev,varNamelana,,,",
    "E,S,ES,varNamelana,,,",
    "E,R,ER,varNamelana,,,",
    "E,s,Es,varNamelana,,,",
    "E,h,Eh,varNamelana,,,",
    "o,a,oZ,pUrvarUpa,efaH paxAnwAxawi (6.1.109),so+ayam",
    "o,aM,oMZ,pUrvarUpa,efaH paxAnwAxawi (6.1.109),so+ayam",
    "o,A,avA,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "o,A,a A,lopa,lopaH SAkalyasya (8.3.19),",
    "o,i,avi,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),viRNo+iha",
    "o,i,a i,lopa,lopaH SAkalyasya (8.3.19),viRNo+iha",
    "o,I,avI,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),viRNo+IyAw",
    "o,I,a I,lopa,lopaH SAkalyasya (8.3.19),viRNo+IyAw",
    "o,u,avu,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),guro+ujJawa",
    "o,u,a u,lopa,lopaH SAkalyasya (8.3.19),guro+ujJawa",
    "o,U,avU,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),guro+UhawAm",
    "o,U,a U,lopa,lopaH SAkalyasya (8.3.19),guro+UhawAm",
    "o,q,avq,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),guro+qcCawa",
    "o,q,a q,lopa,lopaH SAkalyasya (8.3.19),guro+qcCawa",
    "o,Q,avQ,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "o,Q,a Q,lopa,lopaH SAkalyasya (8.3.19),",
    "o,L,avL,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "o,L,a L,lopa,lopaH SAkalyasya (8.3.19),",
    "o,e,ave,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),viRNo+eXawAm",
    "o,e,a e,lopa,lopaH SAkalyasya (8.3.19),viRNo+eXawAm",
    "o,E,avE,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),viRNo+EXewa",
    "o,E,a E,lopa,lopaH SAkalyasya (8.3.19),viRNo+EXewa",
    "o,o,avo,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),",
    "o,o,a o,lopa,lopaH SAkalyasya (8.3.19),",
    "o,O,avO,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),praBo+ORaXam",
    "o,O,a O,lopa,lopaH SAkalyasya (8.3.19),praBo+ORaXam",
    "o,k,ok,varNamelana,,,",
    "o,K,oK,varNamelana,,,",
    "o,g,og,varNamelana,,,",
    "o,G,oG,varNamelana,,,",
    "o,f,of,varNamelana,,,",
    "o,c,oc,varNamelana,,,",
    "o,C,ocC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "o,C,oC,pakRe wugaBAvaH,,,",
    "o,j,oj,varNamelana,,,",
    "o,J,oJ,varNamelana,,,",
    "o,F,oF,varNamelana,,,",
    "o,t,ot,varNamelana,,,",
    "o,T,oT,varNamelana,,,",
    "o,d,od,varNamelana,,,",
    "o,D,oD,varNamelana,,,",
    "o,N,oN,varNamelana,,,",
    "o,w,ow,varNamelana,,,",
    "o,W,oW,varNamelana,,,",
    "o,x,ox,varNamelana,,,",
    "o,X,oX,varNamelana,,,",
    "o,n,on,varNamelana,,,",
    "o,p,op,varNamelana,,,",
    "o,P,oP,varNamelana,,,",
    "o,b,ob,varNamelana,,,",
    "o,B,oB,varNamelana,,,",
    "o,m,om,varNamelana,,,",
    "o,y,oy,varNamelana,,,",
    "o,r,or,varNamelana,,,",
    "o,l,ol,varNamelana,,,",
    "o,v,ov,varNamelana,,,",
    "o,S,oS,varNamelana,,,",
    "o,R,oR,varNamelana,,,",
    "o,s,os,varNamelana,,,",
    "o,h,oh,varNamelana,,,",
    "O,a,Ava,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),gurO+aswi",
    "O,a,A a,lopa,lopaH SAkalyasya (8.3.19),gurO+aswi",
    "O,A,AvA,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlakO+AgawO",
    "O,A,A A,lopa,lopaH SAkalyasya (8.3.19),bAlakO+AgawO",
    "O,i,Avi,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlakO+icCawaH",
    "O,i,A i,lopa,lopaH SAkalyasya (8.3.19),bAlakO+icCawaH",
    "O,I,AvI,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlakO+Ihewe",
    "O,I,A I,lopa,lopaH SAkalyasya (8.3.19),bAlakO+Ihewe",
    "O,u,Avu,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),narO+uxArO",
    "O,u,A u,lopa,lopaH SAkalyasya (8.3.19),narO+uxArO",
    "O,U,AvU,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),rAmO+Uhewe",
    "O,U,A U,lopa,lopaH SAkalyasya (8.3.19),rAmO+Uhewe",
    "O,q,Avq,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlakO+qcCawaH",
    "O,q,A q,lopa,lopaH SAkalyasya (8.3.19),bAlakO+qcCawaH",
    "O,Q,AvQ,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),uBO+QkArayawaH",
    "O,Q,A Q,lopa,lopaH SAkalyasya (8.3.19),uBO+QkArayawaH",
    "O,L,AvL,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),uBO+LkArayawaH",
    "O,L,A L,lopa,lopaH SAkalyasya (8.3.19),uBO+LkArayawaH",
    "O,e,Ave,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),karO+ewO",
    "O,e,A e,lopa,lopaH SAkalyasya (8.3.19),karO+ewO",
    "O,E,AvE,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlakO+EXiRyawAm",
    "O,E,A E,lopa,lopaH SAkalyasya (8.3.19),bAlakO+EXiRyawAm",
    "O,o,Avo,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlO+ojasvinO",
    "O,o,A o,lopa,lopaH SAkalyasya (8.3.19),bAlO+ojasvinO",
    "O,O,AvO,yAnwavAnwa,ecoZyavAyAvaH (6.1.78),bAlO+OnawAm",
    "O,O,A O,lopa,lopaH SAkalyasya (8.3.19),bAlO+OnawAm",
    "O,k,Ok,varNamelana,,,",
    "O,K,OK,varNamelana,,,",
    "O,g,Og,varNamelana,,,",
    "O,G,OG,varNamelana,,,",
    "O,f,Of,varNamelana,,,",
    "O,c,Oc,varNamelana,,,",
    "O,C,OcC,wugAgama -> Scuwva,paxAnwAw vA (6.1.76)-> swoH ScunA ScuH (8.4.40),",
    "O,C,OC,pakRe wugaBAvaH,,,",
    "O,j,Oj,varNamelana,,,",
    "O,J,OJ,varNamelana,,,",
    "O,F,OF,varNamelana,,,",
    "O,t,Ot,varNamelana,,,",
    "O,T,OT,varNamelana,,,",
    "O,d,Od,varNamelana,,,",
    "O,D,OD,varNamelana,,,",
    "O,N,ON,varNamelana,,,",
    "O,w,Ow,varNamelana,,,",
    "O,W,OW,varNamelana,,,",
    "O,x,Ox,varNamelana,,,",
    "O,X,OX,varNamelana,,,",
    "O,n,On,varNamelana,,,",
    "O,p,Op,varNamelana,,,",
    "O,P,OP,varNamelana,,,",
    "O,b,Ob,varNamelana,,,",
    "O,B,OB,varNamelana,,,",
    "O,m,Om,varNamelana,,,",
    "O,y,Oy,varNamelana,,,",
    "O,r,Or,varNamelana,,,",
    "O,l,Ol,varNamelana,,,",
    "O,v,Ov,varNamelana,,,",
    "O,S,OS,varNamelana,,,",
    "O,R,OR,varNamelana,,,",
    "O,s,Os,varNamelana,,,",
    "O,h,Oh,varNamelana,,,",
    "k,a,ga,jaSwva,JalAM jaSoZnwe (8.2.39),samyak+aBihiwam",
    "k,A,gA,jaSwva,JalAM jaSoZnwe (8.2.39),samyak+Aha",
    "k,i,gi,jaSwva,JalAM jaSoZnwe (8.2.39),samyak+icCawi",
    "k,I,gI,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+ISaH",
    "k,u,gu,jaSwva,JalAM jaSoZnwe (8.2.39),wvak+uwpAtyawe",
    "k,U,gU,jaSwva,JalAM jaSoZnwe (8.2.39),samyak+Uhawe",
    "k,q,gq,jaSwva,JalAM jaSoZnwe (8.2.39),wiryak+qcCawi",
    "k,Q,gQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,L,gL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,e,ge,jaSwva,JalAM jaSoZnwe (8.2.39),prAk+eva",
    "k,E,gE,jaSwva,JalAM jaSoZnwe (8.2.39),prAk+EkRyawe",
    "k,o,go,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+ojasvi",
    "k,O,gO,jaSwva,JalAM jaSoZnwe (8.2.39),samyak+ORaXam",
    "k,k,kk,carwva,Kari ca (8.4.55),wiryak+karowi",
    "k,K,kK,carwva,Kari ca (8.4.55),samyak+KAxawi",
    "k,g,gg,jaSwva,JalAM jaS JaSi (8.4.53),wiryak+gacCawi",
    "k,G,gG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "k,f,gf,jaSwva,JalAM jaSoZnwe (8.2.39),",  # if the second word is an anunAsikAxiprawyaya the anunAsika,sanXi is niwya
    "k,f,ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",  # if the second word is an anunAsikAxiprawyaya the anunAsika,sanXi is niwya
    "k,c,kc,carwva,Kari ca (8.4.55),",
    "k,C,kC,carwva,Kari ca (8.4.55),",
    "k,j,gj,jaSwva,JalAM jaS JaSi (8.4.53),xik+jAlam",
    "k,J,gJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "k,F,gF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,F,fF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "k,t,kt,carwva,Kari ca (8.4.55),",
    "k,T,kT,carwva,Kari ca (8.4.55),",
    "k,d,gd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "k,D,gD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "k,N,gN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,N,fN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "k,w,kw,carwva,Kari ca (8.4.55),",
    "k,W,kW,carwva,Kari ca (8.4.55),",
    "k,x,gx,jaSwva,JalAM jaS JaSi (8.4.53),vAk+xevawA",
    "k,X,gX,jaSwva,JalAM jaS JaSi (8.4.53),Xik+Xanagarviwam",
    "k,n,gn,jaSwva,JalAM jaSoZnwe (8.2.39),xik+nAgaH",
    "k,n,fn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),xik+nAgaH",
    "k,p,kp,carwva,Kari ca (8.4.55),",
    "k,P,kP,carwva,Kari ca (8.4.55),",
    "k,b,gb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "k,B,gB,jaSwva,JalAM jaS JaSi (8.4.53),xik+BiH",
    "k,m,gm,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+mayam",
    "k,m,fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),vAk+mayam",
    "k,y,gy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,r,gr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,l,gl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "k,v,gv,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+vyavahAraH",
    "k,S,kS,carwva,Kari ca (8.4.55),vAk+SaraH",
    "k,R,kR,carwva,Kari ca (8.4.55),",
    "k,s,ks,carwva,Kari ca (8.4.55),",
    "k,h,gh,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+hariH",
    "k,h,gG,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),vAk+hariH",
    "K,a,ga,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,A,gA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,i,gi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,I,gI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,u,gu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,U,gU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,q,gq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,Q,gQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,L,gL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,e,ge,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,E,gE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,o,go,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,O,gO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,k,kk,carwva,Kari ca (8.4.55),",
    "K,K,kK,carwva,Kari ca (8.4.55),",
    "K,g,gg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,G,gG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,f,gf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,f,ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "K,c,kc,carwva,Kari ca (8.4.55),",
    "K,C,kC,carwva,Kari ca (8.4.55),",
    "K,j,gj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,J,gJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,F,gF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,F,fF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "K,t,kt,carwva,Kari ca (8.4.55),",
    "K,T,kT,carwva,Kari ca (8.4.55),",
    "K,d,gd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,D,gD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,N,gN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,N,fN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "K,w,kw,carwva,Kari ca (8.4.55),",
    "K,W,kW,carwva,Kari ca (8.4.55),",
    "K,x,gx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,X,gX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,n,gn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,n,fn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "K,p,kp,carwva,Kari ca (8.4.55),",
    "K,P,kP,carwva,Kari ca (8.4.55),",
    "K,b,gb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,B,gB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "K,m,gm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,m,fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "K,y,gy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,r,gr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,l,gl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,v,gv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,S,kS,carwva,Kari ca (8.4.55),",
    "K,R,kR,carwva,Kari ca (8.4.55),",
    "K,s,ks,carwva,Kari ca (8.4.55),",
    "K,h,gh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "K,h,gG,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "g,a,ga,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,A,gA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,i,gi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,I,gI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,u,gu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,U,gU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,q,gq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,Q,gQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,L,gL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,e,ge,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,E,gE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,o,go,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,O,gO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,k,kk,carwva,Kari ca (8.4.55),wAxqg+karmaH",
    "g,K,kK,carwva,Kari ca (8.4.55),kAmaXug+KAxawi",
    "g,g,gg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,G,gG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,f,gf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,f,ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "g,c,kc,carwva,Kari ca (8.4.55),",
    "g,C,kC,carwva,Kari ca (8.4.55),",
    "g,j,gj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,J,gJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,F,gF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,F,fF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "g,t,kt,carwva,Kari ca (8.4.55),",
    "g,T,kT,carwva,Kari ca (8.4.55),",
    "g,d,gd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,D,gD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,N,gN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,N,fN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "g,w,kw,carwva,Kari ca (8.4.55),",
    "g,W,kW,carwva,Kari ca (8.4.55),",
    "g,x,gx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,X,gX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,n,gn,jaSwva,JalAM jaSoZnwe (8.2.39),vAg+niyamaH",
    "g,n,fn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),vAg+niyamaH",
    "g,p,kp,carwva,Kari ca (8.4.55),xig+pAlaH",
    "g,P,kP,carwva,Kari ca (8.4.55),wAxqg+Palam",
    "g,b,gb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,B,gB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "g,m,gm,jaSwva,JalAM jaSoZnwe (8.2.39),vAk+mUlam",
    "g,m,fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),vAk+mUlam",
    "g,y,gy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,r,gr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,l,gl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,v,gv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "g,S,kS,carwva,Kari ca (8.4.55),",
    "g,R,kR,carwva,Kari ca (8.4.55),",
    "g,s,ks,carwva,Kari ca (8.4.55),",
    "g,h,gG,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),vaNik+hasawi",
    "g,h,gh,jaSwva,JalAM jaSoZnwe (8.2.39),vaNik+hasawi",
    "G,a,ga,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,A,gA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,i,gi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,I,gI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,u,gu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,U,gU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,q,gq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,Q,gQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,L,gL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,e,ge,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,E,gE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,o,go,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,O,gO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,k,kk,carwva,Kari ca (8.4.55),",
    "G,K,kK,carwva,Kari ca (8.4.55),",
    "G,g,gg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,G,gG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,f,gf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,f,ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "G,c,kc,carwva,Kari ca (8.4.55),",
    "G,C,kC,carwva,Kari ca (8.4.55),",
    "G,j,gj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,J,gJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,F,gF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,F,fF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "G,t,kt,carwva,Kari ca (8.4.55),",
    "G,T,kT,carwva,Kari ca (8.4.55),",
    "G,d,gd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,D,gD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,N,gN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,N,fN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "G,w,kw,carwva,Kari ca (8.4.55),",
    "G,W,kW,carwva,Kari ca (8.4.55),",
    "G,x,gx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,X,gX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,n,gn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,n,fn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "G,p,kp,carwva,Kari ca (8.4.55),",
    "G,P,kP,carwva,Kari ca (8.4.55),",
    "G,b,gb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,B,gB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "G,m,gm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,m,fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "G,y,gy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,r,gr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,l,gl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,v,gv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,S,kS,carwva,Kari ca (8.4.55),",
    "G,R,kR,carwva,Kari ca (8.4.55),",
    "G,s,ks,carwva,Kari ca (8.4.55),",
    "G,h,gh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "G,h,gG,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "f,a,fa,varNamelana,,,",
    "f,A,fA,varNamelana,,,",
    "f,i,fi,varNamelana,,,",
    "f,I,fI,varNamelana,,,",
    "f,u,fu,varNamelana,,,",
    "f,U,fU,varNamelana,,,",
    "f,q,fq,varNamelana,,,",
    "f,Q,fQ,varNamelana,,,",
    "f,L,fL,varNamelana,,,",
    "f,e,fe,varNamelana,,,",
    "f,E,fE,varNamelana,,,",
    "f,o,fo,varNamelana,,,",
    "f,O,fO,varNamelana,,,",
    "f,k,fk,varNamelana,,,",
    "f,K,fK,varNamelana,,,",
    "f,g,fg,varNamelana,,,",
    "f,G,fG,varNamelana,,,",
    "f,f,ff,varNamelana,,,",
    "f,c,fc,varNamelana,,,",
    "f,C,fC,varNamelana,,,",
    "f,j,fj,varNamelana,,,",
    "f,J,fJ,varNamelana,,,",
    "f,F,fF,varNamelana,,,",
    "f,t,ft,varNamelana,,,",
    "f,T,fT,varNamelana,,,",
    "f,d,fd,varNamelana,,,",
    "f,D,fD,varNamelana,,,",
    "f,N,fN,varNamelana,,,",
    "f,w,fw,varNamelana,,,",
    "f,W,fW,varNamelana,,,",
    "f,x,fx,varNamelana,,,",
    "f,X,fX,varNamelana,,,",
    "f,n,fn,varNamelana,,,",
    "f,p,fp,varNamelana,,,",
    "f,P,fP,varNamelana,,,",
    "f,b,fb,varNamelana,,,",
    "f,B,fB,varNamelana,,,",
    "f,m,fm,varNamelana,,,",
    "f,y,fy,varNamelana,,,",
    "f,r,fr,varNamelana,,,",
    "f,l,fl,varNamelana,,,",
    "f,v,fv,varNamelana,,,",
    "f,S,fkS,kugAgama,fNoH kuktuk Sari (8.3.28),prAf+Sewe",
    "f,S,fKS,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),prAf+Sewe",
    "f,S,fS,kugAgamABAva,,prAf+Sewe",
    "f,R,fkR,kugAgama,fNoH kuktuk Sari (8.3.28),prAf+RaRTaH",
    "f,R,fKR,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),prAf+RaRTaH",
    "f,R,fR,kugAgamABAva,,prAf+RaRTaH",
    "f,s,fks,kugAgamaH,fNoH kuktuk Sari (8.3.28),",
    "f,s,fKs,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),",
    "f,s,fs,kugAgamABAva,,,",
    "f,h,fh,varNamelana,,,",
    "c,a,ja,jaSwva,JalAM jaSoZnwe (8.2.39),ac+anwaH",
    "c,A,jA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,i,ji,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,I,jI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,u,ju,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,U,jU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,q,jq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,Q,jQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,L,jL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,e,je,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,E,jE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,o,jo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,O,jO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,k,ck,carwva,Kari ca (8.4.55),",
    "c,K,cK,carwva,Kari ca (8.4.55),",
    "c,g,jg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,G,jG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,f,jf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,f,Ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "c,c,cc,carwva,Kari ca (8.4.55),",
    "c,C,cC,carwva,Kari ca (8.4.55),",
    "c,j,jj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,J,jJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,F,jF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "c,t,ct,carwva,Kari ca (8.4.55),",
    "c,T,cT,carwva,Kari ca (8.4.55),",
    "c,d,jd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,D,jD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,N,jN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,N,FN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "c,w,cc,Scuwva,swoH ScunA ScuH (8.4.40),",
    "c,W,cC,Scuwva,swoH ScunA ScuH (8.4.40),",
    "c,x,jx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,X,JX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,n,cF,Scuwva,swoH ScunA ScuH (8.4.40),yAc+nA,",
    "c,p,cp,carwva,Kari ca (8.4.55),",
    "c,P,cP,carwva,Kari ca (8.4.55),",
    "c,b,jb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,B,jB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "c,m,jm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,m,Fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "c,y,jy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,r,jr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,l,jl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,v,jv,jaSwva,JalAM jaSoZnwe (8.2.39),ac+varNaH",
    "c,S,cS,carwva,Kari ca (8.4.55),tac+SivaH ??",
    "c,R,cR,carwva,Kari ca (8.4.55),",
    "c,s,cs,carwva,Kari ca (8.4.55),",
    "c,h,jh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "c,h,jJ,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "C,a,ja,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,A,jA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,i,ji,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,I,jI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,u,ju,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,U,jU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,q,jq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,Q,jQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,L,jL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,e,je,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,E,jE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,o,jo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,O,jO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,k,ck,carwva,Kari ca (8.4.55),",
    "C,K,cK,carwva,Kari ca (8.4.55),",
    "C,g,jg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,G,jG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,f,jf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,f,Ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "C,c,cc,carwva,Kari ca (8.4.55),",
    "C,C,cC,carwva,Kari ca (8.4.55),",
    "C,j,jj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,J,jJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,F,jF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "C,t,ct,carwva,Kari ca (8.4.55),",
    "C,T,cT,carwva,Kari ca (8.4.55),",
    "C,d,jd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,D,jD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,N,jN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,N,FN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "C,w,cc,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "C,W,cC,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "C,x,jj,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "C,X,JJ,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "C,n,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "C,n,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "C,p,cp,carwva,Kari ca (8.4.55),",
    "C,P,cP,carwva,Kari ca (8.4.55),",
    "C,b,jb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,B,jB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "C,m,jm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,m,Fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "C,y,jy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,r,jr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,l,jl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,v,jv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,S,cS,carwva,Kari ca (8.4.55),",
    "C,R,cR,carwva,Kari ca (8.4.55),",
    "C,s,cs,carwva,Kari ca (8.4.55),",
    "C,h,jh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "C,h,jJ,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "j,a,ja,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,A,jA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,i,ji,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,I,jI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,u,ju,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,U,jU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,q,jq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,Q,jQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,L,jL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,e,je,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,E,jE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,o,jo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,O,jO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,k,ck,carwva,Kari ca (8.4.55),",
    "j,K,cK,carwva,Kari ca (8.4.55),",
    "j,g,jg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,G,jG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,f,jf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,f,Ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "j,c,cc,carwva,Kari ca (8.4.55),",
    "j,C,cC,carwva,Kari ca (8.4.55),",
    "j,j,jj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,J,jJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,F,jF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "j,t,ct,carwva,Kari ca (8.4.55),",
    "j,T,cT,carwva,Kari ca (8.4.55),",
    "j,d,jd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,D,jD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,N,jN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,N,FN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "j,w,cc,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "j,W,cC,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "j,x,jj,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "j,X,jJ,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "j,n,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "j,n,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "j,p,cp,carwva,Kari ca (8.4.55),",
    "j,P,cP,carwva,Kari ca (8.4.55),",
    "j,b,jb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,B,jB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "j,m,jm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,m,Fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "j,y,jy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,r,jr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,l,jl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,v,jv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "j,S,cS,carwva,Kari ca (8.4.55),",
    "j,R,cR,carwva,Kari ca (8.4.55),",
    "j,s,cs,carwva,Kari ca (8.4.55),",
    "j,h,jJ,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),aj+halO",
    "j,h,jh,jaSwva,JalAM jaSoZnwe (8.2.39),aj+halO",
    "J,a,ja,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,A,jA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,i,ji,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,I,jI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,u,ju,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,U,jU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,q,jq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,Q,jQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,L,jL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,e,je,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,E,jE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,o,jo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,O,jO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,k,ck,carwva,Kari ca (8.4.55),",
    "J,K,cK,carwva,Kari ca (8.4.55),",
    "J,g,jg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,G,jG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,f,jf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,f,Ff,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "J,c,cc,carwva,Kari ca (8.4.55),",
    "J,C,cC,carwva,Kari ca (8.4.55),",
    "J,j,jj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,J,jJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,F,jF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "J,t,ct,carwva,Kari ca (8.4.55),",
    "J,T,cT,carwva,Kari ca (8.4.55),",
    "J,d,jd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,D,jD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,N,jN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,N,FN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "J,w,cc,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "J,W,cC,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "J,x,jj,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "J,X,jJ,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "J,n,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "J,n,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "J,p,cp,carwva,Kari ca (8.4.55),",
    "J,P,cP,carwva,Kari ca (8.4.55),",
    "J,b,jb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,B,jB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "J,m,jm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,m,Fm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "J,y,jy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,r,jr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,l,jl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,v,jv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "J,S,cS,carwva,Kari ca (8.4.55),",
    "J,R,cR,carwva,Kari ca (8.4.55),",
    "J,s,cs,carwva,Kari ca (8.4.55),",
    "J,h,jJ,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "J,h,jh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "F,a,Fa,varNamelana,,,",
    "F,A,FA,varNamelana,,,",
    "F,i,Fi,varNamelana,,,",
    "F,I,FI,varNamelana,,,",
    "F,u,Fu,varNamelana,,,",
    "F,U,FU,varNamelana,,,",
    "F,q,Fq,varNamelana,,,",
    "F,Q,FQ,varNamelana,,,",
    "F,L,FL,varNamelana,,,",
    "F,e,Fe,varNamelana,,,",
    "F,E,FE,varNamelana,,,",
    "F,o,Fo,varNamelana,,,",
    "F,O,FO,varNamelana,,,",
    "F,k,Fk,varNamelana,,,",
    "F,K,FK,varNamelana,,,",
    "F,g,Fg,varNamelana,,,",
    "F,G,FG,varNamelana,,,",
    "F,f,Ff,varNamelana,,,",
    "F,c,Fc,varNamelana,,,",
    "F,C,FC,varNamelana,,,",
    "F,j,Fj,varNamelana,,,",
    "F,J,FJ,varNamelana,,,",
    "F,F,FF,varNamelana,,,",
    "F,t,Ft,varNamelana,,,",
    "F,T,FT,varNamelana,,,",
    "F,d,Fd,varNamelana,,,",
    "F,D,FD,varNamelana,,,",
    "F,N,FN,varNamelana,,,",
    "F,w,Fc,Scuwva,swoH ScunA ScuH (8.4.40),",
    "F,W,FC,Scuwva,swoH ScunA ScuH (8.4.40),",
    "F,x,Fj,Scuwva,swoH ScunA ScuH (8.4.40),",
    "F,X,FJ,Scuwva,swoH ScunA ScuH (8.4.40),",
    "F,n,FF,Scuwva,swoH ScunA ScuH (8.4.40),",
    "F,p,Fp,varNamelana,,,",
    "F,P,FP,varNamelana,,,",
    "F,b,Fb,varNamelana,,,",
    "F,B,FB,varNamelana,,,",
    "F,m,Fm,varNamelana,,,",
    "F,y,Fy,varNamelana,,,",
    "F,r,Fr,varNamelana,,,",
    "F,l,Fl,varNamelana,,,",
    "F,v,Fv,varNamelana,,,",
    "F,S,FS,varNamelana,,,",
    "F,R,FR,varNamelana,,,",
    "F,s,Fs,varNamelana,,,",
    "F,h,Fh,varNamelana,,,",
    "t,a,da,jaSwva,JalAM jaSoZnwe (8.2.39),lit+aswi",
    "t,A,dA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,i,di,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,I,dI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,u,du,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,U,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,q,dq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,Q,dQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,L,dL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,e,de,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,E,dE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,o,do,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,O,dO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,k,tk,carwva,Kari ca (8.4.55),",
    "t,K,tK,carwva,Kari ca (8.4.55),",
    "t,g,dg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,G,dG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,f,df,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,f,Nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "t,c,tc,carwva,Kari ca (8.4.55),",
    "t,C,tC,carwva,Kari ca (8.4.55),",
    "t,j,dj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,J,dJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,F,dF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,F,NF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "t,t,tt,carwva,Kari ca (8.4.55),",
    "t,T,tT,carwva,Kari ca (8.4.55),",
    "t,d,dd,jaSwva,JalAM jaS JaSi (8.4.53),maDulit+dayawe",
    "t,D,dD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,N,dN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "t,w,t w,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "t,W,t W,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "t,x,d x,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "t,X,d X,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "t,n,Nn,jaSwva -> Rtuwva-> wanniReXa-> anunAsika,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "t,n,d n,jaSwva -> Rtuwva-> wanniReXa-> anunAsikABAva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "t,p,tp,carwva,Kari ca (8.4.55),",
    "t,P,tP,carwva,Kari ca (8.4.55),",
    "t,b,db,jaSwva,JalAM jaS JaSi (8.4.53),",
    "t,B,dB,jaSwva,JalAM jaS JaSi (8.4.53),parivrAt+BiH",
    "t,m,dm,jaSwva,JalAM jaSoZnwe (8.2.39),parivrAt+miwram",
    "t,m,Nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),parivrAt+miwram",
    "t,y,dy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,r,dr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,l,dl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,v,dv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "t,S,tS,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39)-> Kari ca (8.4.55),maXulit+Sewe",
    "t,R,tR,carwva,Kari ca (8.4.55),",
    "t,s,tws,jaSwva -> XudAgama-> Rtuwve-> wanniReXe-> carwva,JalAM jaSoZnwe (8.2.39)-> daH si Xut (8.3.29)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),Rat+sanwaH",
    "t,s,ts,jaSwva -> XudAgamABAvaH-> Rtuwve-> wanniReXe-> carwva,JalAM jaSoZnwe (8.2.39)-> daH si Xut (8.3.29)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),Rat+sanwaH",
    "t,h,dh,jaSwva,JalAM jaSoZnwe (8.2.39),parivrAt+hasawi",
    "t,h,dD,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),parivrAt+hasawi",
    "T,a,da,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,A,dA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,i,di,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,I,dI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,u,du,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,U,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,q,dq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,Q,dQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,L,dL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,e,de,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,E,dE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,o,do,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,O,dO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,k,tk,carwva,Kari ca (8.4.55),",
    "T,K,tK,carwva,Kari ca (8.4.55),",
    "T,g,dg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,G,dG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,f,df,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,f,Nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,c,tc,carwva,Kari ca (8.4.55),",
    "T,C,tC,carwva,Kari ca (8.4.55),",
    "T,j,dj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,J,dJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,F,dF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,F,NF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,t,tt,carwva,Kari ca (8.4.55),",
    "T,T,tT,carwva,Kari ca (8.4.55),",
    "T,d,dd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,D,dD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,N,dN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,w,tw,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "T,W,tW,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "T,x,dx,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "T,X,dX,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "T,n,Nn,jaSwva -> Rtuwva-> wanniReXa-> anunAsika,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,n,dn,jaSwva -> Rtuwva-> wanniReXa-> anunAsikABAva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,p,tp,carwva,Kari ca (8.4.55),",
    "T,P,tP,carwva,Kari ca (8.4.55),",
    "T,b,db,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,B,dB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "T,m,dm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,m,Nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "T,y,dy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,r,dr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,l,dl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,v,dv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,S,tS,carwva,Kari ca (8.4.55),",
    "T,R,tR,carwva,Kari ca (8.4.55),",
    "T,s,tR,Rtuwva -> carwva,RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "T,h,dh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "T,h,dD,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "d,a,da,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,A,dA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,i,di,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,I,dI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,u,du,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,U,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,q,dq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,Q,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,L,dL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,e,de,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,E,dE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,o,do,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,O,dO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,k,tk,carwva,Kari ca (8.4.55),viSvarAd+kuwra",
    "d,K,tK,carwva,Kari ca (8.4.55),Rad+KAxyAni",
    "d,g,dg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,G,dG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,f,df,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,f,Nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "d,c,tc,carwva,Kari ca (8.4.55),",
    "d,C,tC,carwva,Kari ca (8.4.55),",
    "d,j,dj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,J,dJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,F,dF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,F,NF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "d,t,tt,carwva,Kari ca (8.4.55),",
    "d,T,tT,carwva,Kari ca (8.4.55),",
    "d,d,dd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,D,dD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,N,dN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "d,w,tw,Rtuwva -> wanniReXa-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "d,W,tW,Rtuwva -> wanniReXa-> carwva,RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "d,x,dx,Rtuwva -> RtuwvaniReXaH,RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "d,X,dX,Rtuwva -> RtuwvaniReXaH,RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "d,n,Nn,Rtuwva -> wanniReXa-> anunAsika,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "d,n,dn,Rtuwva -> wanniReXa-> anunAsikABAva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "d,p,tp,carwva,Kari ca (8.4.55),virAd+puruRaH",
    "d,P,tP,carwva,Kari ca (8.4.55),",
    "d,b,db,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,B,dB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "d,m,dm,jaSwva,JalAM jaSoZnwe (8.2.39),Rad+mayUKAH,",
    "d,m,Nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),Rad+mayUKAH,",
    "d,y,dy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,r,dr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,l,dl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,v,dv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "d,S,tS,carwva,Kari ca (8.4.55),",
    "d,R,tR,carwva,Kari ca (8.4.55),",
    "d,s,ts,Rtuwva -> wanniReXa-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "d,h,dD,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),Rad+hayaH",
    "d,h,dh,jaSwva,JalAM jaSoZnwe (8.2.39),Rad+hayaH",
    "D,a,da,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,A,dA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,i,di,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,I,dI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,u,du,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,U,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,q,dq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,Q,dQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,L,dL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,e,de,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,E,dE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,o,do,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,O,dO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,k,tk,carwva,Kari ca (8.4.55),",
    "D,K,tK,carwva,Kari ca (8.4.55),",
    "D,g,dg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,G,dG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,f,df,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,f,Nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,c,tc,carwva,Kari ca (8.4.55),",
    "D,C,tC,carwva,Kari ca (8.4.55),",
    "D,j,dj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,J,dJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,F,dF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,F,NF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,t,tt,carwva,Kari ca (8.4.55),",
    "D,T,tT,carwva,Kari ca (8.4.55),",
    "D,d,dd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,D,dD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,N,dN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,w,tw,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "D,W,tW,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "D,x,dx,Rtuwva -> RtuwvaniReXaH,RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "D,X,dX,Rtuwva -> RtuwvaniReXaH,RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "D,n,Nn,jaSwva -> Rtuwva-> wanniReXa-> anunAsika,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,n,dn,jaSwva -> Rtuwva-> wanniReXa-> anunAsikABAva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,p,tp,carwva,Kari ca (8.4.55),",
    "D,P,tP,carwva,Kari ca (8.4.55),",
    "D,b,db,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,B,dB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "D,m,dm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,m,Nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "D,y,dy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,r,dr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,l,dl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,v,dv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,S,tS,carwva,Kari ca (8.4.55),",
    "D,R,tR,carwva,Kari ca (8.4.55),",
    "D,s,ts,Rtuwva -> carwva,RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "D,h,dh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "D,h,dD,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "N,a,Na,varNamelana,,,",
    "N,A,NA,varNamelana,,,",
    "N,i,Ni,varNamelana,,,",
    "N,I,NI,varNamelana,,,",
    "N,u,Nu,varNamelana,,,",
    "N,U,NU,varNamelana,,,",
    "N,q,Nq,varNamelana,,,",
    "N,Q,NQ,varNamelana,,,",
    "N,L,NL,varNamelana,,,",
    "N,e,Ne,varNamelana,,,",
    "N,E,NE,varNamelana,,,",
    "N,o,No,varNamelana,,,",
    "N,O,NO,varNamelana,,,",
    "N,k,Nk,varNamelana,,,",
    "N,K,NK,varNamelana,,,",
    "N,g,Ng,varNamelana,,,",
    "N,G,NG,varNamelana,,,",
    "N,f,Nf,varNamelana,,,",
    "N,c,Nc,varNamelana,,,",
    "N,C,NC,varNamelana,,,",
    "N,j,Nj,varNamelana,,,",
    "N,J,NJ,varNamelana,,,",
    "N,F,NF,varNamelana,,,",
    "N,t,Nt,varNamelana,,,",
    "N,T,NT,varNamelana,,,",
    "N,d,Nd,varNamelana,,,",
    "N,D,ND,varNamelana,,,",
    "N,N,NN,varNamelana,,,",
    "N,w,Nw,varNamelana,,,",
    "N,W,NW,varNamelana,,,",
    "N,x,Nx,varNamelana,,,",
    "N,X,NX,varNamelana,,,",
    "N,n,NN,varNamelana,,,",
    "N,p,Np,varNamelana,,,",
    "N,P,NP,varNamelana,,,",
    "N,b,Nb,varNamelana,,,",
    "N,B,NB,varNamelana,,,",
    "N,m,Nm,varNamelana,,,",
    "N,y,Ny,varNamelana,,,",
    "N,r,Nr,varNamelana,,,",
    "N,l,Nl,varNamelana,,,",
    "N,v,Nv,varNamelana,,,",
    "N,S,NtS,tugAgama,fNoH kuktuk Sari (8.3.28),",
    "N,S,NTS,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),",
    "N,S,NS,tugAgamABAva,,,",
    "N,R,NtR,tugAgama,fNoH kuktuk Sari (8.3.28),sugaN+RaRTaH",
    "N,R,NTR,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),sugaN+RaRTaH",
    "N,R,NR,tugAgamABAva,,sugaN+RaRTaH",
    "N,s,Nts,tugAgama,fNoH kuktuk Sari (8.3.28),sugaN+sarawi",
    "N,s,NTs,xviwIyavarNAxeSa,cayoH xviwIyAH Sari pORkarasAxeriwi vAcyam (vA 5023),sugaN+sarawi",
    "N,s,Ns,tugAgamABAva,,sugaN+sarawi",
    "N,h,Nh,varNamelana,,,",
    "w,a,xa,jaSwva,JalAM jaSoZnwe (8.2.39),svargAw+api",
    "w,A,xA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,i,xi,jaSwva,JalAM jaSoZnwe (8.2.39),mahaw+ixam",
    "w,I,xI,jaSwva,JalAM jaSoZnwe (8.2.39),jagaw+ISaH",
    "w,u,xu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,U,xU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,q,xq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,Q,xQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,L,xL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,e,xe,jaSwva,JalAM jaSoZnwe (8.2.39),wAvaw+enam",
    "w,E,xE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,o,xo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,O,xO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,k,wk,carwva,Kari ca (8.4.55),",
    "w,K,wK,carwva,Kari ca (8.4.55),",
    "w,g,xg,jaSwva,JalAM jaS JaSi (8.4.53),uw+gamaH",
    "w,G,xG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "w,f,xf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "w,f,nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "w,c,cc,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),saw+ciw",
    "w,C,cC,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),bqhaw+Cawram",
    "w,j,jj,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),bqhaw+jayaH",
    "w,J,jJ,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),bqhaw+JaRaH",
    "w,F,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "w,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "w,t,tt,jaSwva -> Rtuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),bqhaw+tIkA",
    "w,T,tT,jaSwva -> Rtuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),ewaw+TakkuraH",
    "w,d,dd,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),bqhaw+damaru",
    "w,D,dD,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),bqhaw+DakkA",
    "w,N,dN,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),waw+NakAraH",
    "w,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),waw+NakAraH",
    "w,w,ww,carwva,Kari ca (8.4.55),",
    "w,W,wW,carwva,Kari ca (8.4.55),",
    "w,x,xx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "w,X,xX,jaSwva,JalAM jaS JaSi (8.4.53),mahaw+XanuH",
    "w,n,xn,jaSwva,JalAM jaSoZnwe (8.2.39),jagaw+niyAmakaH,",
    "w,n,nn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),jagaw+niyAmakaH,",
    "w,p,wp,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39)-> Kari ca (8.4.55),pataw+pataxiwi",
    "w,P,wP,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39)-> Kari ca (8.4.55),waw+Palam",
    "w,b,xb,jaSwva,JalAM jaS JaSi (8.4.53),waw+balam",
    "w,B,xB,jaSwva,JalAM jaS JaSi (8.4.53),waw+BAraH",
    "w,m,xm,jaSwva,JalAM jaSoZnwe (8.2.39),waw+mawiH",
    "w,m,nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),waw+mawiH",
    "w,y,xy,jaSwva,JalAM jaSoZnwe (8.2.39),waw+yaSaH",
    "w,r,xr,jaSwva,JalAM jaSoZnwe (8.2.39),waw+rasaH",
    "w,l,ll,jaSwva -> parasavarNa,JalAM jaSoZnwe (8.2.39)-> worli (8.4.60),calaw+lAfgalam",
    "w,v,xv,jaSwva,JalAM jaSoZnwe (8.2.39),asmAw+vacanAw",
    "w,S,cS,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),waw+Scuwvam",
    "w,R,wR,carwva,Kari ca (8.4.55),",
    "w,s,ws,carwva,Kari ca (8.4.55),",
    "w,h,xh,jaSwva,JalAM jaSoZnwe (8.2.39),syAw+hali",
    "w,h,xX,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),syAw+hali",
    "W,a,xa,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,A,xA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,i,xi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,I,xI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,u,xu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,U,xU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,q,xq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,Q,xQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,L,xL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,e,xe,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,E,xE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,o,xo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,O,xO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,k,wk,carwva,Kari ca (8.4.55),",
    "W,K,wK,carwva,Kari ca (8.4.55),",
    "W,g,xg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,G,xG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,f,xf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,f,nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "W,c,cc,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "W,C,cC,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "W,j,jj,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "W,J,jJ,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "W,F,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "W,F,FF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "W,t,tt,jaSwva -> Rtuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "W,T,tT,jaSwva -> Rtuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "W,d,dd,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "W,D,dD,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "W,N,dN,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "W,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "W,w,ww,carwva,Kari ca (8.4.55),",
    "W,W,wW,carwva,Kari ca (8.4.55),",
    "W,x,xx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,X,xX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,n,xn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,n,nn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "W,p,wp,carwva,Kari ca (8.4.55),",
    "W,P,wP,carwva,Kari ca (8.4.55),",
    "W,b,xb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,B,xB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "W,m,xm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,m,nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "W,y,xy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,r,xr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,l,ll,jaSwva -> parasavarNa,JalAM jaSoZnwe (8.2.39)-> worli (8.4.60),",
    "W,v,xv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,S,cS,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "W,R,wR,carwva,Kari ca (8.4.55),",
    "W,s,ws,carwva,Kari ca (8.4.55),",
    "W,h,xh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "W,h,xX,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "x,a,xa,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,A,xA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,i,xi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,I,xI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,u,xu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,U,xU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,q,xq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,Q,xQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,L,xL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,e,xe,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,E,xE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,o,xo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,O,xO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,k,wk,carwva,Kari ca (8.4.55),vipax+kAlaH",
    "x,K,wK,carwva,Kari ca (8.4.55),",
    "x,g,xg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,G,xG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,f,xf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,f,nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "x,c,cc,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "x,C,cC,Scuwva -> carwva,swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "x,j,jj,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),suhqx+jagAma,",
    "x,J,jJ,Scuwva -> jaSwva,swoH ScunA ScuH (8.4.40)-> JalAM jaS JaSi (8.4.53),",
    "x,F,jF,Scuwva,swoH ScunA ScuH (8.4.40),",
    "x,F,nF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "x,t,tt,Rtuwva -> carwva,RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "x,T,tT,Rtuwva -> carwva,RtunA RtuH (8.4.41)-> Kari ca (8.4.55),Sarax+TambaraH",
    "x,d,dd,Rtuwva -> jaSwva,RtunA RtuH (8.4.41)-> JalAM jaS JaSi (8.4.53),",
    "x,D,dD,Rtuwva -> jaSwva,RtunA RtuH (8.4.41)-> JalAM jaS JaSi (8.4.53),ewax+Dakka",
    "x,N,NN,Rtuwva,RtunA RtuH (8.4.41),",
    "x,N,dN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "x,w,ww,carwva,Kari ca (8.4.55),",
    "x,W,wW,carwva,Kari ca (8.4.55),",
    "x,x,xx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,X,xX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,n,xn,jaSwva,JalAM jaSoZnwe (8.2.39),wax+nayawi,",
    "x,n,nn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),wax+nayawi,",
    "x,p,wp,carwva,Kari ca (8.4.55),asmax+puwraH",
    "x,P,wP,carwva,Kari ca (8.4.55),",
    "x,b,xb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,B,xB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "x,m,xm,jaSwva,JalAM jaSoZnwe (8.2.39),wax+mafgalam,",
    "x,m,nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),wax+mafgalam,",
    "x,y,xy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,r,xr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,l,ll,jaSwva -> parasavarNa,JalAM jaSoZnwe (8.2.39)-> worli (8.4.60),wax+layaH",
    "x,v,xv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "x,S,cS,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "x,R,wR,carwva,Kari ca (8.4.55),",
    "x,s,ws,carwva,Kari ca (8.4.55),kakux+sWaH",
    "x,h,xh,jaSwva,JalAM jaSoZnwe (8.2.39),wax+hiwam,",
    "x,h,xX,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),wax+hiwam,",
    "*x,h,xh,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),wax+hiwam,",
    "X,a,xa,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,A,xA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,i,xi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,I,xI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,u,xu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,U,xU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,q,xq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,Q,xQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,L,xL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,e,xe,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,E,xE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,o,xo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,O,xO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,k,wk,carwva,Kari ca (8.4.55),",
    "X,K,wK,carwva,Kari ca (8.4.55),",
    "X,g,xg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,G,xG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,f,xf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,f,nf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "X,c,cc,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "X,C,cC,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "X,j,jj,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "X,J,jJ,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "X,F,jF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "X,F,nF,jaSwva -> Scuwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40),",
    "X,t,tt,jaSwva -> Rtuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "X,T,tT,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)-> Kari ca (8.4.55),",
    "X,d,dd,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "X,D,dD,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "X,N,dN,jaSwva -> Rtuwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41),",
    "X,N,NN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "X,w,ww,carwva,Kari ca (8.4.55),",
    "X,W,wW,carwva,Kari ca (8.4.55),",
    "X,x,xx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,X,xX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,n,xn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,n,nn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "X,p,wp,carwva,Kari ca (8.4.55),",
    "X,P,wP,carwva,Kari ca (8.4.55),",
    "X,b,xb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,B,xB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "X,m,xm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,m,nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "X,y,xy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,r,xr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,l,ll,jaSwva -> parasavarNa,JalAM jaSoZnwe (8.2.39)-> worli (8.4.60),",
    "X,v,xv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,S,cS,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "X,R,wR,carwva,Kari ca (8.4.55),",
    "X,s,ws,carwva,Kari ca (8.4.55),",
    "X,h,xh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "X,h,xX,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    # "n,a,na,varNamelana,,,", # Commented by Amba
    # "n,A,nA,varNamelana,,kavIn+Ahvayasva", # Commented by Amba
    # "n,i,ni,varNamelana,,,", # Commented by Amba
    # "n,I,nI,varNamelana,,,", # Commented by Amba
    # "n,u,nu,varNamelana,,,", # Commented by Amba
    # "n,U,nU,varNamelana,,,", # Commented by Amba
    # "n,q,nq,varNamelana,,,", # Commented by Amba
    # "n,Q,nQ,varNamelana,,,", # Commented by Amba
    # "n,L,nL,varNamelana,,,", # Commented by Amba
    # "n,e,ne,varNamelana,,,", # Commented by Amba
    # "n,E,nE,varNamelana,,,", # Commented by Amba
    # "n,o,no,varNamelana,,,", # Commented by Amba
    # "n,O,nO,varNamelana,,,", # Commented by Amba
    # "n,k,nk,varNamelana,,,", # Commented by Amba
    # "n,K,nK,varNamelana,,,", # Commented by Amba
    # "n,g,ng,varNamelana,,,", # Commented by Amba
    # "n,G,nG,varNamelana,,,", # Commented by Amba
    # "n,f,nf,varNamelana,,,", # Commented by Amba
    "n,k,fk,varNamelana,,,",  # Added by Amba
    "n,K,fK,varNamelana,,,",  # Added by Amba
    "n,g,fg,varNamelana,,,",  # Added by Amba
    "n,G,fG,varNamelana,,,",  # Added by Amba
    "n,f,f,varNamelana,,,",   # Added by Amba
    "n,c,Fc,varNamelana,,,",
    "n,C,FC,varNamelana,,,",
    "n,j,Fj,Scuwva,swoH ScunA ScuH (8.4.40),",
    "n,J,FJ,varNamelana,,,",   # Commented by Amba
    # "n,F,nF,varNamelana,,,", # Commented by Amba
    "n,F,F,varNamelana,,,",    # Added by Amba
    # "n,t,nt,varNamelana,,,", # Commented by Amba
    # "n,T,nT,varNamelana,,,", # Commented by Amba
    # "n,d,nd,varNamelana,,,", # Commented by Amba
    "n,t,Nt,varNamelana,,,",   # Added by Amba
    "n,T,NT,varNamelana,,,",   # Added by Amba
    "n,d,Nd,varNamelana,,,",   # Added by Amba
    "n,D,ND,Rtuwva,RtunA RtuH (8.4.41),",
    # "n,N,nN,varNamelana,,,", # Commented by Amba
    # "n,w,nw,varNamelana,,,", # Commented by Amba
    # "n,W,nW,varNamelana,,,", # Commented by Amba
    "n,x,nx,varNamelana,,,",
    "n,X,nX,varNamelana,,,",
    "n,n,nn,varNamelana,,,",
    "n,p,np,varNamelana,,,",  # naSca apaxAnwSca Jali
    "n,P,nP,varNamelana,,,",  # naSca apaxAnwSca Jali
    "n,b,nb,varNamelana,,,",  # naSca apaxAnwSca Jali
    "n,B,nB,varNamelana,,,",  # naSca apaxAnwSca Jali
    "n,m,nm,varNamelana,,,",  # naSca apaxAnwSca Jali
    "n,y,ny,varNamelana,,,",
    "n,r,nr,varNamelana,,,",
    "n,l,lzl,parasavarNa,worli (8.4.60),",
    "n,v,nv,varNamelana,,,",
    # "n,S,FcS,wugAgama -> Scuwva-> carwva,Si wuk (8.3.31)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "n,S,FcS,wugAgama -> Scuwva-> Scuwva,Si wuk (8.3.31)-> swoH ScunA ScuH (8.4.40)-> SwoH ScunA ScuH (8.4.40),",
    "n,S,FS,Scuwva,swoH ScunA ScuH (8.4.40),",
    "n,R,nR,varNamelana,,,",
    "n,s,nws,XudAgama -> carwva,naSca (8.3.30)-> Kari ca (8.4.55),san+saH",
    "n,s,ns,pakRe XudaBAva,naSca (8.3.30),san+saH",
    "n,h,nh,varNamelana,,,",
    "m,k,fk,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),evam+kqwvA",  # this rule is only aplicable in paxAnwa.
    "m,k,M k,anusvAra,moZnusvAraH (8.3.23),evam+kqwvA",  # this rule is only aplicable in paxAnwa.
    "m,K,fK,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),Palam+KAxiwvA",
    "m,K,M K,anusvAra,moZnusvAraH (8.3.23),Palam+KAxiwvA",
    "m,g,fg,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),ApaNam+gawvA",
    "m,g,M g,anusvAra,moZnusvAraH (8.3.23),ApaNam+gawvA",
    "m,G,fG,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,G,M G,anusvAra,moZnusvAraH (8.3.23),",
    "m,f,ff,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,f,M f,anusvAra,moZnusvAraH (8.3.23),",
    "m,c,Fc,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,c,M c,anusvAra,moZnusvAraH (8.3.23),",
    "m,C,FC,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,C,M C,anusvAra,moZnusvAraH (8.3.23),",
    "m,j,Fj,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,j,M j,anusvAra,moZnusvAraH (8.3.23),",
    "m,J,FJ,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,J,M J,anusvAra,moZnusvAraH (8.3.23),",
    "m,F,FF,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,F,M F,anusvAra,moZnusvAraH (8.3.23),",
    "m,t,Nt,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,t,M t,anusvAra,moZnusvAraH (8.3.23),",
    "m,T,NT,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,T,M T,anusvAra,moZnusvAraH (8.3.23),",
    "m,d,Nd,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,d,M d,anusvAra,moZnusvAraH (8.3.23),",
    "m,D,ND,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,D,M D,anusvAra,moZnusvAraH (8.3.23),",
    "m,N,NN,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,N,M N,anusvAra,moZnusvAraH (8.3.23),",
    "m,w,nw,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,w,M w,anusvAra,moZnusvAraH (8.3.23),",
    "m,W,nW,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,W,M W,anusvAra,moZnusvAraH (8.3.23),",
    "m,x,nx,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,x,M x,anusvAra,moZnusvAraH (8.3.23),",
    "m,X,nX,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,X,M X,anusvAra,moZnusvAraH (8.3.23),",
    "m,n,nn,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,n,M n,anusvAra,moZnusvAraH (8.3.23),",
    "m,p,mp,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,p,M p,anusvAra,moZnusvAraH (8.3.23),",
    "m,P,mP,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,P,M P,anusvAra,moZnusvAraH (8.3.23),",
    "m,b,mb,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,b,M b,anusvAra,moZnusvAraH (8.3.23),",
    "m,B,mB,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,B,M B,anusvAra,moZnusvAraH (8.3.23),",
    "m,m,mm,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,m,M m,anusvAra,moZnusvAraH (8.3.23),",
    "m,y,zy,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,y,M y,anusvAra,moZnusvAraH (8.3.23),",
    "m,r,M r,anusvAra,moZnusvAraH (8.3.23),karuNam+roxiwi",
    "m,l,zll,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,l,M l,anusvAra,moZnusvAraH (8.3.23),",
    "m,v,zv,anusvAra -> parasavarNa,moZnusvAraH (8.3.23)-> vA paxAnwasya (8.4.59),",
    "m,v,M v,anusvAra,moZnusvAraH (8.3.23),",
    "m,S,M S,anusvAra,moZnusvAraH (8.3.23),harim+Srayawe",
    "m,R,M R,anusvAra,moZnusvAraH (8.3.23),",
    "m,s,M s,anusvAra,moZnusvAraH (8.3.23),mAlAyAm+sUwram",
    "m,h,M h,anusvAra,moZnusvAraH (8.3.23),maXura+hasawi",
    "p,a,ba,jaSwva,JalAM jaSoZnwe (8.2.39),sup+anwam",
    "p,A,bA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,i,bi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,I,bI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,u,bu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,U,bU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,q,bq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,Q,bQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,L,bL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,e,be,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,E,bE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,o,bo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,O,bO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,k,pk,carwva,Kari ca (8.4.55),",
    "p,K,pK,carwva,Kari ca (8.4.55),",
    "p,g,bg,jaSwva,JalAM jaS JaSi (8.4.53),ap+gataH",
    "p,G,bG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,f,bf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,f,mf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "p,c,pc,carwva,Kari ca (8.4.55),",
    "p,C,pC,carwva,Kari ca (8.4.55),",
    "p,j,bj,jaSwva,JalAM jaS JaSi (8.4.53),ap+jam",
    "p,J,bJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,F,bF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,F,mF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "p,t,pt,carwva,Kari ca (8.4.55),",
    "p,T,pT,carwva,Kari ca (8.4.55),",
    "p,d,bd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,D,bD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,N,bN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,N,mN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "p,w,pw,carwva,Kari ca (8.4.55),",
    "p,W,pW,carwva,Kari ca (8.4.55),",
    "p,x,bx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,X,bX,jaSwva,JalAM jaS JaSi (8.4.53),ap+XiH",
    "p,n,bn,jaSwva,JalAM jaSoZnwe (8.2.39),ap+naxI",
    "p,n,mn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),ap+naxI",
    "p,p,pp,carwva,Kari ca (8.4.55),",
    "p,P,pP,carwva,Kari ca (8.4.55),",
    "p,b,bb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "p,B,bB,jaSwva,JalAM jaS JaSi (8.4.53),kakup+BiH",
    "p,m,bm,jaSwva,JalAM jaSoZnwe (8.2.39),ap+mayam,",
    "p,m,mm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),ap+mayam,",
    "p,y,by,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,r,br,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,l,bl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,v,bv,jaSwva,JalAM jaSoZnwe (8.2.39),sup+viBakwiH",
    "p,S,pS,carwva,Kari ca (8.4.55),gup+Sewe",
    "p,R,pR,carwva,Kari ca (8.4.55),",
    "p,s,ps,carwva,Kari ca (8.4.55),",
    "p,h,bh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "p,h,bB,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "P,a,ba,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,A,bA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,i,bi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,I,bI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,u,bu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,U,bU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,q,bq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,Q,bQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,L,bL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,e,be,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,E,bE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,o,bo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,O,bO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,k,pk,carwva,Kari ca (8.4.55),",
    "P,K,pK,carwva,Kari ca (8.4.55),",
    "P,g,bg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,G,bG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,f,bf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,f,mf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "P,c,pc,carwva,Kari ca (8.4.55),",
    "P,C,pC,carwva,Kari ca (8.4.55),",
    "P,j,bj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,J,bJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,F,bF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,F,mF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "P,t,pt,carwva,Kari ca (8.4.55),",
    "P,T,pT,carwva,Kari ca (8.4.55),",
    "P,d,bd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,D,bD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,N,bN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,N,mN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "P,w,pw,carwva,Kari ca (8.4.55),",
    "P,W,pW,carwva,Kari ca (8.4.55),",
    "P,x,bx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,X,bX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,n,bn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,n,mn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "P,p,pp,carwva,Kari ca (8.4.55),",
    "P,P,pP,carwva,Kari ca (8.4.55),",
    "P,b,bb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,B,bB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "P,m,bm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,m,mm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "P,y,by,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,r,br,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,l,bl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,v,bv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,S,pS,carwva,Kari ca (8.4.55),",
    "P,R,pR,carwva,Kari ca (8.4.55),",
    "P,s,ps,carwva,Kari ca (8.4.55),",
    "P,h,bh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "P,h,bB,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "b,a,ba,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,A,bA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,i,bi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,I,bI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,u,bu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,U,bU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,q,bq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,Q,bQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,L,bL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,e,be,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,E,bE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,o,bo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,O,bO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,k,pk,carwva,Kari ca (8.4.55),",
    "b,K,pK,carwva,Kari ca (8.4.55),",
    "b,g,bg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,G,bG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,f,bf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,f,mf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "b,c,pc,carwva,Kari ca (8.4.55),",
    "b,C,pC,carwva,Kari ca (8.4.55),",
    "b,j,bj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,J,bJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,F,bF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,F,mF,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "b,t,pt,carwva,Kari ca (8.4.55),",
    "b,T,pT,carwva,Kari ca (8.4.55),",
    "b,d,bd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,D,bD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,N,bN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,N,mN,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "b,w,pw,carwva,Kari ca (8.4.55),",
    "b,W,pW,carwva,Kari ca (8.4.55),",
    "b,x,bx,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,X,bX,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,n,bn,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,n,mn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "b,p,pp,carwva,Kari ca (8.4.55),",
    "b,P,pP,carwva,Kari ca (8.4.55),",
    "b,b,bb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,B,bB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "b,m,bm,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,m,mm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "b,y,by,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,r,br,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,l,bl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,v,bv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "b,S,pS,carwva,Kari ca (8.4.55),",
    "b,R,pR,carwva,Kari ca (8.4.55),",
    "b,s,ps,carwva,Kari ca (8.4.55),",
    "b,h,bB,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),ab+hqxO",
    "b,h,bh,jaSwva,JalAM jaSoZnwe (8.2.39),ab+hqxO",
    "B,a,ba,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,A,bA,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,i,bi,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,I,bI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,u,bu,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,U,bU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,q,bq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,Q,bQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,L,bL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,e,be,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,E,bE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,o,bo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,O,bO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,k,pk,carwva,Kari ca (8.4.55),",
    "B,K,pK,carwva,Kari ca (8.4.55),",
    "B,g,bg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "B,G,bG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "B,f,bf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,f,mf,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "B,c,pc,carwva,Kari ca (8.4.55),",
    "B,C,pC,carwva,Kari ca (8.4.55),",
    "B,j,bj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "B,J,bJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "B,F,bF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "B,F,mF,anunasika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "B,t,pt,carwva,Kari ca (8.4.55),",
    "B,T,pT,carwva,Kari ca (8.4.55),",
    "B,d,bd,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,D,bD,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,N,bN,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,N,mN,anunasika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "B,w,pw,carwva,Kari ca (8.4.55),",
    "B,W,pW,carwva,Kari ca (8.4.55),",
    "B,x,bx,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,X,bX,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,n,bn,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,n,mn,anunasika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "B,p,pp,carwva,Kari ca (8.4.55),",
    "B,P,pP,carwva,Kari ca (8.4.55),",
    "B,b,bb,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,B,bB,jaswva,JalAM jaS JaSi (8.4.53),",
    "B,m,bm,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,m,mm,anunasika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "B,y,by,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,r,br,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,l,bl,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,v,bv,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,S,pS,carwva,Kari ca (8.4.55),",
    "B,R,pR,carwva,Kari ca (8.4.55),",
    "B,s,ps,carwva,Kari ca (8.4.55),",
    "B,h,bh,jaswva,JalAM jaSoZnwe (8.2.39),",
    "B,h,bb,pUrvasavarna,Jayo hoZnyawarasyAm (8.4.62),",
    "m,a,ma,varNamelana,,,",
    "m,A,mA,varNamelana,,,",
    "m,i,mi,varNamelana,,,",
    "m,I,mI,varNamelana,,,",
    "m,u,mu,varNamelana,,,param+uwkqRtam",
    "m,U,mU,varNamelana,,,",
    "m,q,mq,varNamelana,,,",
    "m,Q,mQ,varNamelana,,,",
    "m,L,mL,varNamelana,,,",
    "m,e,me,varNamelana,,,",
    "m,E,mE,varNamelana,,,",
    "m,o,mo,varNamelana,,,",
    "m,O,mO,varNamelana,,,",
    "M,a,Ma,varNamelana,,,",
    "M,A,MA,varNamelana,,,",
    "M,i,Mi,varNamelana,,,",
    "M,I,MI,varNamelana,,,",
    "M,u,Mu,varNamelana,,paraM+uwkqrtam",
    "M,U,MU,varNamelana,,,",
    "M,q,Mq,varNamelana,,,",
    "M,Q,MQ,varNamelana,,,",
    "M,L,ML,varNamelana,,,",
    "M,e,Me,varNamelana,,,",
    "M,E,ME,varNamelana,,,",
    "M,o,Mo,varNamelana,,,",
    "M,O,MO,varNamelana,,,",
    "M,k,fk,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,K,fK,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,g,fg,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,G,fG,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,f,ff,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,c,Fc,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,C,FC,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,j,Fj,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),sawrum+jahi",
    "M,J,FJ,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,F,FF,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,t,Nt,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,T,NT,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,d,Nd,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,D,ND,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,N,NN,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,w,nw,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,W,nW,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,x,nx,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,X,nX,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,n,nn,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,p,mp,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,P,mP,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,b,mb,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,B,mB,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,m,mm,parasavarNa,anusvArasya yayi parasavarNaH (8.4.58),",
    "M,y,My,varNamelana,,,",
    "M,r,Mr,varNamelana,,,",
    "M,l,Ml,varNamelana,,,",
    "M,v,Mv,varNamelana,,,",
    "M,S,MS,varNamelana,,,",
    "M,R,MR,varNamelana,,,",
    "M,s,Ms,varNamelana,,,",
    "M,h,Mh,varNamelana,,,",
    "y,a,ya,varNamelana,,,",
    "y,A,yA,varNamelana,,,",
    "y,i,yi,varNamelana,,,",
    "y,I,yI,varNamelana,,,",
    "y,u,yu,varNamelana,,,",
    "y,U,yU,varNamelana,,,",
    "y,q,yq,varNamelana,,,",
    "y,Q,yQ,varNamelana,,,",
    "y,L,yL,varNamelana,,,",
    "y,e,ye,varNamelana,,,",
    "y,E,yE,varNamelana,,,",
    "y,o,yo,varNamelana,,,",
    "y,O,yO,varNamelana,,,",
    "y,k,yk,varNamelana,,,",
    "y,K,yK,varNamelana,,,",
    "y,g,yg,varNamelana,,,",
    "y,G,yG,varNamelana,,,",
    "y,f,yf,varNamelana,,,",
    "y,c,yc,varNamelana,,,",
    "y,C,yC,varNamelana,,,",
    "y,j,yj,varNamelana,,,",
    "y,J,yJ,varNamelana,,,",
    "y,F,yF,varNamelana,,,",
    "y,t,yt,varNamelana,,,",
    "y,T,yT,varNamelana,,,",
    "y,d,yd,varNamelana,,,",
    "y,D,yD,varNamelana,,,",
    "y,n,yn,varNamelana,,,",
    "y,w,yw,varNamelana,,,",
    "y,W,yW,varNamelana,,,",
    "y,x,yx,varNamelana,,,",
    "y,X,yX,varNamelana,,,",
    "y,n,yn,varNamelana,,,",
    "y,p,yp,varNamelana,,,",
    "y,P,yP,varNamelana,,,",
    "y,b,yb,varNamelana,,,",
    "y,B,yB,varNamelana,,,",
    "y,m,ym,varNamelana,,,",
    "y,y,yy,varNamelana,,,",
    "y,r,yr,varNamelana,,,",
    "y,l,yl,varNamelana,,,",
    "y,v,yv,varNamelana,,,",
    "y,S,yS,varNamelana,,,",
    "y,R,yR,varNamelana,,,",
    "y,s,ys,varNamelana,,,",
    "y,h,yh,varNamelana,,,",
    # "r,a,h a,visarga,,,",
    # "r,a,h a,visarga,,,",
    # "r,i,h i,visarga,,,",
    # "r,i,h i,visarga,,,",
    # "r,u,h u,visarga,,,",
    # "r,u,h u,visarga,,,",
    # "r,q,h q,visarga,,,",
    # "r,q,h q,visarga,,,",
    # "r,l,h l,visarga,,,",
    # "r,e,h e,visarga,,,",
    # "r,e,h e,visarga,,,",
    # "r,o,h o,visarga,,,",
    # "r,o,h o,visarga,,,",
    # "r,k,h k,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,k,h k,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,g,h g,visarga,,,",
    # "r,g,h g,visarga,,,",
    # "r,f,h f,visarga,,,",
    # "r,c,h c,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,c,h c,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,j,h j,visarga,,,",
    # "r,j,h j,visarga,,,",
    # "r,f,h f,visarga,,,",
    # "r,t,h t,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,t,h t,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,d,h d,visarga,,,",
    # "r,d,h d,visarga,,,",
    # "r,n,h n,visarga,,,",
    # "r,w,h w,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,w,h w,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,x,h x,visarga,,,",
    # "r,x,h x,visarga,,,",
    # "r,n,h n,visarga,,,",
    # "r,p,h p,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,p,h p,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,b,h b,visarga,,,",
    # "r,b,h b,visarga,,,",
    # "r,m,h m,visarga,,,",
    # "r,y,h y,visarga,,,",
    "ar,r,A r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),punar+ramawe",
    "ur,r,U r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "ir,r,I r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "Ar,r,A r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "Ur,r,U r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "Ir,r,I r,rePalopa -> xIrGaH,ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    # "r,l,h l,visarga,,,",
    # "r,v,h v,visarga,,,",
    # "r,s,h s,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,r,h r,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,s,h s,visarga,KaravasAnayorvisarjanIyaH (8.3.15),",
    # "r,h,h h,visarga,,,",
    "l,a,la,varNamelana,,,",
    "l,A,lA,varNamelana,,,",
    "l,i,li,varNamelana,,,",
    "l,I,lI,varNamelana,,,",
    "l,u,lu,varNamelana,,,",
    "l,U,lU,varNamelana,,,",
    "l,q,lq,varNamelana,,,",
    "l,Q,lQ,varNamelana,,,",
    "l,L,lL,varNamelana,,,",
    "l,e,le,varNamelana,,,",
    "l,E,lE,varNamelana,,,",
    "l,o,lo,varNamelana,,,",
    "l,O,lO,varNamelana,,,",
    "l,k,lk,varNamelana,,,",
    "l,K,lK,varNamelana,,,",
    "l,g,lg,varNamelana,,,",
    "l,G,lG,varNamelana,,,",
    "l,f,lf,varNamelana,,,",
    "l,c,lc,varNamelana,,,",
    "l,C,lC,varNamelana,,,",
    "l,j,lj,varNamelana,,,",
    "l,J,lJ,varNamelana,,,",
    "l,F,lF,varNamelana,,,",
    "l,t,lt,varNamelana,,,",
    "l,T,lT,varNamelana,,,",
    "l,d,ld,varNamelana,,,",
    "l,D,lD,varNamelana,,,",
    "l,N,lN,varNamelana,,,",
    "l,w,lw,varNamelana,,,",
    "l,W,lW,varNamelana,,,",
    "l,x,lx,varNamelana,,,",
    "l,X,lX,varNamelana,,,",
    "l,n,ln,varNamelana,,,",
    "l,p,lp,varNamelana,,,",
    "l,P,lP,varNamelana,,,",
    "l,b,lb,varNamelana,,,",
    "l,B,lB,varNamelana,,,",
    "l,m,lm,varNamelana,,,",
    "l,y,ly,varNamelana,,,",
    "l,r,lr,varNamelana,,,",
    "l,l,ll,varNamelana,,,",
    "l,v,lv,varNamelana,,,",
    "l,S,lS,varNamelana,,,",
    "l,R,lR,varNamelana,,,",
    "l,s,ls,varNamelana,,,",
    "l,h,lh,varNamelana,,,",
    "v,a,va,varNamelana,,,",
    "v,A,vA,varNamelana,,,",
    "v,i,vi,varNamelana,,,",
    "v,I,vI,varNamelana,,,",
    "v,u,vu,varNamelana,,,",
    "v,U,vU,varNamelana,,,",
    "v,q,vq,varNamelana,,,",
    "v,Q,vQ,varNamelana,,,",
    "v,L,vL,varNamelana,,,",
    "v,e,ve,varNamelana,,,",
    "v,E,vE,varNamelana,,,",
    "v,o,vo,varNamelana,,,",
    "v,O,vO,varNamelana,,,",
    "v,k,vk,varNamelana,,,",
    "v,K,vK,varNamelana,,,",
    "v,g,vg,varNamelana,,,",
    "v,G,vG,varNamelana,,,",
    "v,f,vf,varNamelana,,,",
    "v,c,vc,varNamelana,,,",
    "v,C,vC,varNamelana,,,",
    "v,j,vj,varNamelana,,,",
    "v,J,vJ,varNamelana,,,",
    "v,F,vF,varNamelana,,,",
    "v,t,vt,varNamelana,,,",
    "v,T,vT,varNamelana,,,",
    "v,d,vd,varNamelana,,,",
    "v,D,vD,varNamelana,,,",
    "v,N,vN,varNamelana,,,",
    "v,w,vw,varNamelana,,,",
    "v,W,vW,varNamelana,,,",
    "v,x,vx,varNamelana,,,",
    "v,X,vX,varNamelana,,,",
    "v,n,vn,varNamelana,,,",
    "v,p,vp,varNamelana,,,",
    "v,P,vP,varNamelana,,,",
    "v,b,vb,varNamelana,,,",
    "v,B,vB,varNamelana,,,",
    "v,m,vm,varNamelana,,,",
    "v,y,vy,varNamelana,,,",
    "v,r,vr,varNamelana,,,",
    "v,l,vl,varNamelana,,,",
    "v,v,vv,varNamelana,,,",
    "v,S,vS,varNamelana,,,",
    "v,R,vR,varNamelana,,,",
    "v,s,vs,varNamelana,,,",
    "v,h,vh,varNamelana,,,",
    "S,a,ja,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,A,jA,jaSwva,JalAM jaSoZnwe (8.2.39),RaR+AnanaH",
    "S,i,ji,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,I,jI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,u,ju,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,U,jU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,q,jq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,Q,jQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,L,jL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,e,je,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,E,jE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,o,jo,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,O,jO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,k,ck,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,K,cK,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,g,jg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,G,jG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,f,jf,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,c,cc,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,C,cC,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,j,jj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,J,jJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,F,jF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,t,ct,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,T,cT,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,d,jd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,D,jD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,N,jN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,N,FN,anunAsika-yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "S,w,cw,jaSwva -> ScuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> SwoH ScunA ScuH (8.4.40)[Scuwve prApwe]-> SAw (8.4.44)-> Kari ca (8.4.55),",
    "S,W,cW,jaSwva -> ScuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> SwoH ScunA ScuH (8.4.40)[Scuwve prApwe]-> SAw (8.4.44)-> Kari ca (8.4.55),",
    "S,x,jx,jaSwva -> ScuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> SwoH ScunA ScuH (8.4.40)[Scuwve prApwe]-> SAw (8.4.44),",
    "S,X,jX,jaSwva -> ScuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> SwoH ScunA ScuH (8.4.40)[Scuwve prApwe]-> SAw (8.4.44),",
    "S,n,jn,jaSwva -> ScuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> SwoH ScunA ScuH (8.4.40)[Scuwve prApwe]-> SAw (8.4.44),",
    "S,n,Fn,anunAsika-yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "S,p,cp,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,P,cP,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,b,jb,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,B,jB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "S,m,jm,jaSwva,JalAM jaSoZnwe (8.2.39),jyowiR+maw",
    "S,y,jy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,r,jr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,l,jl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,v,jv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,S,RS,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,R,cR,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "S,s,cs,jaSwva -> Scuwva-> carwva,JalAM jaSoZnwe (8.2.39)-> swoH ScunA ScuH (8.4.40)-> Kari ca (8.4.55),",
    "S,h,jh,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "S,h,jJ,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    "R,a,da,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,A,dA,jaSwva,JalAM jaSoZnwe (8.2.39),RaR+AnanaH",
    "R,i,di,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,I,dI,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,u,du,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,U,dU,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,q,dq,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,Q,dQ,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,L,dL,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,e,de,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,E,dE,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,o,do,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,O,dO,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,k,tk,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,K,tK,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,g,dg,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,G,dG,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,f,df,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,c,tc,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,C,tC,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,j,dj,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,J,dJ,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,F,dF,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,t,tt,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,T,tT,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,d,dd,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,D,dD,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,N,dN,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,N,NN,anunAsika-yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "R,w,tw,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "R,W,tW,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "R,x,dx,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),RaR+xarSanAni",
    "R,X,dX,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "R,n,dn,jaSwva -> RtuwvaniReXaH,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42),",
    "R,n,Nn,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "R,p,tp,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,P,tP,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,b,db,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,B,dB,jaSwva,JalAM jaS JaSi (8.4.53),",
    "R,m,dm,jaSwva,JalAM jaSoZnwe (8.2.39),jyowiR+maw",
    "R,m,Nm,anunAsika,yaroZnunAsikeZnunAsiko vA (8.4.45),",
    "R,y,dy,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,r,dr,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,l,dl,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,v,dv,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,S,RS,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,R,tR,jaSwva -> carwva,JalAM jaSoZnwe (8.2.39) -> Kari ca (8.4.55),",
    "R,s,ts,jaSwva -> RtuwvaniReXaH-> carwva,JalAM jaSoZnwe (8.2.39)-> RtunA RtuH (8.4.41)[Rtuwve prApwe]-> na paxAnwAttoranAm (8.4.42)-> Kari ca (8.4.55),",
    "R,h,dD,jaSwva,JalAM jaSoZnwe (8.2.39),",
    "R,h,dh,pUrvasavarNa,Jayo hoZnyawarasyAm (8.4.62),",
    #'[^a]s
    "s,a,H a,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "as,a,oZ,ruwva -> uwva-> guNa-> pUrvarupa,sasajuRo ruH (8.2.66)-> awo rorapluwAxapluwe (6.1.113)-> Ax guNaH (6.1.87)-> efaH paxAnwAxawi (6.1.109),rAmaH+api",
    "as,aM,oMZ,ruwva -> uwva-> guNa-> pUrvarupa,sasajuRo ruH (8.2.66)-> awo rorapluwAxapluwe (6.1.113)-> Ax guNaH (6.1.87)-> efaH paxAnwAxawi (6.1.109),rAmaH+api",
    "s,A,H A,ruwva -> visarga,sasajuRo ruH (8.2.66),",
    "s,i,H i,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,I,H I,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,u,H u,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,U,H U,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,q,H q,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,Q,H Q,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,L,H L,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,e,H e,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,E,H E,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,o,H o,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,O,H O,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,k,H k,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,K,H K,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,g,H g,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,g,rg,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,G,H G,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,G,rG,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,f,H f,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,f,r f,ruwva -> visarga,sasajuRo ruH (8.2.66)",
    "s,c,Sc,Scuwva,swoH ScunA ScuH (8.4.40),manas+cafcalam",
    "s,C,SC,Scuwva,swoH ScunA ScuH (8.4.40),amas+cawrah",
    "s,j,Sj,Scuwva,swoH ScunA ScuH (8.4.40),",
    "s,J,SJ,Scuwva,swoH ScunA ScuH (8.4.40),",
    "s,F,SF,Scuwva,swoH ScunA ScuH (8.4.40),",
    "s,t,Rt,Rtuwva,RtunA RtuH (8.4.41),tavargas+taxih",
    "s,T,RT,Rtuwva,RtunA RtuH (8.4.41),wanus+tafkarah",
    "s,d,Rd,Rtuwva,RtunA RtuH (8.4.41),",
    "s,D,RD,Rtuwva,RtunA RtuH (8.4.41),",
    "s,N,RN,Rtuwva,RtunA RtuH (8.4.41),",
    "s,w,H w,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,W,H W,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,x,H x,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,x,rx,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,X,H X,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,X,rX,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,n,H n,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,n,rn,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,p,H p,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,P,H P,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,b,H b,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,b,rb,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,B,H B,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,B,rB,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,m,H m,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,m,rm,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,y,H y,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,y,ry,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,r,H r,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,r,rr,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,l,H l,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,l,rl,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,v,H v,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,v,rv,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "s,S,SS,Scuwva,swoH ScunA ScuH (8.4.40),sisus+sewe",
    "s,R,RR,Rtuwva,RtunA RtuH (8.4.41),ramas+rartah",
    "s,s,H s,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,h,H h,ruwva -> visarga,sasajuRo ruH (8.2.66)-> KaravasAnayorvisarjanIyaH (8.3.15),",
    "s,h,rh,ruwva -> visarga,sasajuRo ruH (8.2.66)",  # Added by Amba; not followed by Kar
    "h,a,ha,varNamelana,,,",
    "h,A,hA,varNamelana,,,",
    "h,i,hi,varNamelana,,,",
    "h,I,hI,varNamelana,,,",
    "h,u,hu,varNamelana,,,",
    "h,U,hU,varNamelana,,,",
    "h,q,hq,varNamelana,,,",
    "h,Q,hQ,varNamelana,,,",
    "h,L,hL,varNamelana,,,",
    "h,e,he,varNamelana,,,",
    "h,E,hE,varNamelana,,,",
    "h,o,ho,varNamelana,,,",
    "h,O,hO,varNamelana,,,",
    "h,k,hk,varNamelana,,,",
    "h,K,hK,varNamelana,,,",
    "h,g,hg,varNamelana,,,",
    "h,G,hG,varNamelana,,,",
    "h,f,hf,varNamelana,,,",
    "h,c,hc,varNamelana,,,",
    "h,C,hC,varNamelana,,,",
    "h,j,hj,varNamelana,,,",
    "h,J,hJ,varNamelana,,,",
    "h,F,hF,varNamelana,,,",
    "h,t,ht,varNamelana,,,",
    "h,T,hT,varNamelana,,,",
    "h,d,hd,varNamelana,,,",
    "h,D,hD,varNamelana,,,",
    "h,N,hN,varNamelana,,,",
    "h,w,hw,varNamelana,,,",
    "h,W,hW,varNamelana,,,",
    "h,x,hx,varNamelana,,,",
    "h,X,hX,varNamelana,,,",
    "h,n,hn,varNamelana,,,",
    "h,p,hp,varNamelana,,,",
    "h,P,hP,varNamelana,,,",
    "h,b,hb,varNamelana,,,",
    "h,B,hB,varNamelana,,,",
    "h,m,hm,varNamelana,,,",
    "h,y,hy,varNamelana,,,",
    "h,r,hr,varNamelana,,,",
    "h,l,hl,varNamelana,,,",
    "h,v,hv,varNamelana,,,",
    "h,S,hS,varNamelana,,,",
    "h,R,hR,varNamelana,,,",
    "h,s,hs,varNamelana,,,",
    "h,h,hh,varNamelana,,,",
    "aH,a,oZ,ruwva -> uwva-> guNa-> pUrvarupa,sasajuRo ruH (8.2.66)-> awo rorapluwAxapluwe (6.1.113)-> Ax guNaH (6.1.87)-> efaH paxAnwAxawi (6.1.109),rAmaH+api",
    "aH,aM,oMZ,ruwva -> uwva-> guNa-> pUrvarupa,sasajuRo ruH (8.2.66)-> awo rorapluwAxapluwe (6.1.113)-> Ax guNaH (6.1.87)-> efaH paxAnwAxawi (6.1.109),rAmaH+api",
    "aH,A,a A,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmaH+Aswe",
    "aH,A,ayA,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBagoaGo apUrvasya yoZSi (8.3.17),rAmaH+Aswe",
    "aH,i,a i,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmaH+iha",
    "aH,i,ayi,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBagoaGo apUrvasya yoZSi (8.3.17),rAmaH+iha",
    "aH,I,a I,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmaH+Ihawe",
    "aH,I,ayI,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),rAmaH+Ihawe",
    "aH,u,a u,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,u,ayu,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,U,a U,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,U,ayU,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,q,a q,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,q,ayq,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,Q,a Q,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,Q,ayQ,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,L,a L,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,L,ayL,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,e,a e,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,e,aye,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,E,a E,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,E,ayE,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,o,a o,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,o,ayo,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,O,a O,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "aH,O,ayO,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "aH,S,aSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "aH,S,aH S,visarga,vA Sari (8.3.36),",
    "aH,R,aRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "aH,R,aH R,visarga,vA Sari (8.3.36),",
    "aH,s,ass,sawva,visarjanIyasya saH (8.3.34),",
    "aH,s,aH s,visarga,vA Sari (8.3.36),",
    "AH,a,A a,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmAH+awra",
    "AH,a,Aya,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),rAmAH+awra",
    "AH,A,A A,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmAH+Asawe",
    "AH,A,AyA,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),rAmAH+Asawe",
    "AH,i,A i,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmAH+iha",
    "AH,i,Ayi,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),rAmAH+iha",
    "AH,I,A I,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),rAmaH+Ihanwe",
    "AH,I,AyI,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),rAmaH+Ihanwe",
    "AH,u,A u,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,u,Ayu,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,U,A U,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,U,AyU,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,q,A q,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,q,Ayq,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,Q,A Q,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,Q,AyQ,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,L,A L,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,L,AyL,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,e,A e,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,e,Aye,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,E,A E,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,E,AyE,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,o,A o,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,o,Ayo,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,O,A O,ruwva -> yawva-> lopa,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17)-> lopaH SAkalyasya (8.3.19),",
    "AH,O,AyO,ruwva -> yawva,sasajuRo ruH (8.2.66)-> BoBago aGo apUrvasya yoZSi (8.3.17),",
    "AH,S,ASS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "AH,S,AH S,visarga,vA Sari (8.3.36),",
    "AH,R,ARR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "AH,R,AH R,visarga,vA Sari (8.3.36),",
    "AH,s,Ass,sawva,visarjanIyasya saH (8.3.34),",
    "AH,s,AH s,visarga,vA Sari (8.3.36),",
    "iH,r,I r,rePaH -> rePalopa-> xIrGaH,sasajuRo ruH (8.2.66)-> ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),hariH+ramyaH",
    "iH,S,iSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "iH,S,iH S,visargaH,vA Sari (8.3.36),",
    "iH,R,iRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "iH,R,iH R,visarga,vA Sari (8.3.36),",
    "iH,s,iss,sawva,visarjanIyasya saH (8.3.34),",
    "iH,s,iH s,visarga,vA Sari (8.3.36),",
    "IH,r,I r,rePaH -> rePalopa-> xIrGaH,sasajuRo ruH (8.2.66)-> ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "IH,S,ISS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "IH,S,IH S,visarga,vA Sari (8.3.36),",
    "IH,R,IRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "IH,R,IH R,visarga,vA Sari (8.3.36),",
    "IH,s,Iss,sawva,visarjanIyasya saH (8.3.34),",
    "IH,s,IH s,visarga,vA Sari (8.3.36),",
    "uH,r,U r,rePaH -> rePalopa-> xIrGaH,sasajuRo ruH (8.2.66)-> ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "uH,S,uSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "uH,S,uH S,visarga,vA Sari (8.3.36),",
    "uH,R,uRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "uH,R,uH R,visarga,vA Sari (8.3.36),",
    "uH,s,uss,sawva,visarjanIyasya saH (8.3.34),",
    "uH,s,uH s,visarga,vA Sari (8.3.36),",
    "UH,r,U r,rePaH -> rePalopa-> xIrGaH,sasajuRo ruH (8.2.66)-> ro ri (8.3.14)-> Dralope pUrvasya xIrGoZNaH (6.3.111),",
    "UH,S,USS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "UH,S,UH S,visarga,vA Sari (8.3.36),",
    "UH,R,URR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "UH,R,UH R,visarga,vA Sari (8.3.36),",
    "UH,s,Uss,sawva,visarjanIyasya saH (8.3.34),",
    "UH,s,UH s,visarga,vA Sari (8.3.36),",
    "qH,r,qrr,rePaH,sasajuRo ruH (8.2.66),",
    "qH,S,qSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "qH,S,qH S,visarga,vA Sari (8.3.36),",
    "qH,R,qRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "qH,R,qH R,visarga,vA Sari (8.3.36),",
    "qH,s,qss,sawva,visarjanIyasya saH (8.3.34),",
    "qH,s,qH s,visarga,vA Sari (8.3.36),",
    "QH,r,Qrr,rePaH,sasajuRo ruH (8.2.66),",
    "QH,S,QSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "QH,S,QH S,visarga,vA Sari (8.3.36),",
    "QH,R,QRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "QH,R,QH R,visarga,vA Sari (8.3.36),",
    "QH,s,Qss,sawva,visarjanIyasya saH (8.3.34),",
    "QH,s,QH s,visarga,vA Sari (8.3.36),",
    "QH,h,Qrh,rePaH,sasajuRo ruH (8.2.66),",
    "LH,r,Lrr,rePaH,sasajuRo ruH (8.2.66),",
    "LH,S,LSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "LH,S,LH S,visarga,vA Sari (8.3.36),",
    "LH,R,LRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "LH,R,LH R,visarga,vA Sari (8.3.36),",
    "LH,s,Lss,sawva,visarjanIyasya saH (8.3.34),",
    "LH,s,LH s,visarga,vA Sari (8.3.36),",
    "eH,r,err,rePaH,sasajuRo ruH (8.2.66),",
    "eH,S,eSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "eH,S,eH S,visarga,vA Sari (8.3.36),",
    "eH,R,eRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "eH,R,eH R,visarga,vA Sari (8.3.36),",
    "eH,s,ess,sawva,visarjanIyasya saH (8.3.34),",
    "eH,s,eH s,visarga,vA Sari (8.3.36),",
    "oH,r,orr,rePaH,sasajuRo ruH (8.2.66),",
    "oH,S,oSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "oH,S,oH S,visarga,vA Sari (8.3.36),",
    "oH,R,oRR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "oH,R,oH R,visarga,vA Sari (8.3.36),",
    "oH,s,oss,sawva,visarjanIyasya saH (8.3.34),",
    "oH,s,oH s,visarga,vA Sari (8.3.36),",
    "EH,r,Err,rePaH,sasajuRo ruH (8.2.66),",
    "EH,S,ESS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "EH,S,EH S,visarga,vA Sari (8.3.36),",
    "EH,R,ERR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "EH,R,EH R,visarga,vA Sari (8.3.36),",
    "EH,s,Ess,sawva,visarjanIyasya saH (8.3.34),",
    "EH,s,EH s,visarga,vA Sari (8.3.36),",
    "OH,r,Orr,rePaH,sasajuRo ruH (8.2.66),",
    "OH,S,OSS,sawva -> Scuwva,visarjanIyasya saH (8.3.34)-> swoH ScunA ScuH (8.4.40),",
    "OH,S,OH S,visarga,vA Sari (8.3.36),",
    "OH,R,ORR,sawva -> Rtuwva,visarjanIyasya saH (8.3.34)-> RtunA RtuH (8.4.41),",
    "OH,R,OH R,visarga,vA Sari (8.3.36),",
    "OH,s,Oss,sawva,visarjanIyasya saH (8.3.34),",
    "OH,s,OH s,visarga,vA Sari (8.3.36),",
    "H,k,><k,jihvAmUlIya,kupvo><ka><pO ca (8.3.37),",
    "H,k,H k,visarga,kupvo><ka><pO ca (8.3.37),",
    "H,K,><K,jihvAmUlIya,kupvo><ka><pO ca (8.3.37),",
    "H,K,H K,visarga,kupvo><ka><pO ca (8.3.37),",
    "H,p,><p,upaXmAnIya,kupvo><ka><pO ca (8.3.37),",
    "H,p,H p,visarga,kupvo><ka><pO ca (8.3.37),",
    "H,P,><P,upaXmAnIya,kupvo><ka><pO ca (8.3.37),",
    "H,P,H P,visarga,kupvo><ka><pO ca (8.3.37),",
]
